@@ -47,6 +47,7 @@
 #include <qprogressdialog.h>
 #include <qsemimodal.h>
 #include <qcheckbox.h>
+#include <qcombobox.h>
 
 /** \class KChooseDir
  * Used for asking the user for a folder.
@@ -69,26 +70,32 @@ public:
 	 *              this is used for completion of partial urls
 	 */
 	static KURL getDir(QString text,const KURL& url, const KURL& cwd);
-	static KURL getDir(QString text,const KURL& url, const KURL& cwd, bool & preserveDate );
+	static KURL getDir(QString text,const KURL& url, const KURL& cwd, bool & preserveAttrs );
+	static KURL getDir(QString text,const KURL& url, const KURL& cwd, bool & preserveAttrs, KURL &baseURL );
 };
 
 class KURLRequesterDlgForCopy : public KDialogBase {
   Q_OBJECT
 public:
-	KURLRequesterDlgForCopy( const QString& url, const QString& text, bool presDate,
-				QWidget *parent, const char *name, bool modal=true );
+	KURLRequesterDlgForCopy( const QString& url, const QString& text, bool presAttrs,
+				QWidget *parent, const char *name, bool modal=true, KURL baseURL = KURL() );
 	KURLRequesterDlgForCopy();
 
 	KURL selectedURL() const;
-	bool preserveDate();        
+	KURL baseURL() const;
+	bool preserveAttrs();
+	bool copyDirStructure();
         
 	KURLRequester *urlRequester();
 private slots:
 	void slotClear();
 	void slotTextChanged(const QString &);
+	void slotDirStructCBChanged();
 private:
 	KURLRequester *urlRequester_;
-	QCheckBox *preserveDateCB;
+	QComboBox *baseUrlCombo;
+	QCheckBox *preserveAttrsCB;
+	QCheckBox *copyDirStructureCB;
 };
 
 class KRGetDate : public KDialog {
@@ -105,20 +112,4 @@ private:
   QDate chosenDate, originalDate;
 };
 
-class QCheckbox;
-
-class UserSelectionModeDlg: public KDialogBase {
-  Q_OBJECT
-public:
-	static int createCustomMode(QWidget *parent);
-	~UserSelectionModeDlg();
-	
-protected:
-	UserSelectionModeDlg(QWidget *parent);
-	QCheckBox *qtSelection, *leftButtonSelects, *leftButtonPreserves, *shiftCtrlLeftSelects;
-	QCheckBox *rightButtonSelects, *rightButtonPreserves, *shiftCtrlRightSelects, *spaceMovesDown;
-	QCheckBox *insertMovesDown, *spaceCalcSpace, *contextMenuImmediate;
-};
-
-
 #endif
