@@ -39,12 +39,12 @@
 #include <klocale.h>
 #include <qtooltip.h>
 
-DiskUsageGUI::DiskUsageGUI( QString openDir, QWidget* parent, char *name ) 
+DiskUsageGUI::DiskUsageGUI( KURL openDir, QWidget* parent, const char *name ) 
   : QDialog( parent, name, false, 0 ), exitAtFailure( true )
 {  
   setCaption( i18n("Krusader::Disk Usage") );
   
-  baseDirectory = vfs::fromPathOrURL( openDir );
+  baseDirectory = openDir;
   if( !newSearch() )
     return;
   
@@ -81,7 +81,7 @@ DiskUsageGUI::DiskUsageGUI( QString openDir, QWidget* parent, char *name )
   QToolTip::add( btnDetailed, i18n( "Detailed view" ) );
 
   btnFilelight = new QToolButton( duTools, "btnFilelight" );
-  btnFilelight->setIconSet( QIconSet(krLoader->loadIcon("none",KIcon::Desktop)) );
+  btnFilelight->setIconSet( QIconSet(krLoader->loadIcon("kr_diskusage",KIcon::Desktop)) );
   btnFilelight->setToggleButton( true );
   QToolTip::add( btnFilelight, i18n( "Filelight view" ) );
     
