@@ -178,6 +178,8 @@ class DULinesToolTip : public QToolTip
 public:
     DULinesToolTip( DiskUsage *usage, QWidget *parent, QListView *lv );
     void maybeTip( const QPoint &pos );
+
+    virtual ~DULinesToolTip() {}
 private:
     QListView *view;
     DiskUsage *diskUsage;
@@ -293,7 +295,7 @@ void DULines::slotDirChanged( Directory *dirEntry )
   { 
     File *item = *it;
     
-    QString fileName = item->fileName();
+    QString fileName = item->name();
     
     unsigned int italicStart = fileName.length();
     
