@@ -53,24 +53,13 @@
 QPtrList<KrViewer> KrViewer::viewers;
 
 KrViewer::KrViewer( QWidget *parent, const char *name ) :
-KParts::MainWindow( parent, name ), manager( this, this ), tabBar( this ) {
+KParts::MainWindow( parent, name ), manager( this, this ), tabBar( this ), returnFocusTo( 0 ), returnFocusTab( 0 ),
+                                    reservedKeys(), reservedKeyIDs() {
 
 	//setWFlags(WType_TopLevel | WDestructiveClose);
 	setXMLFile( "krviewer.rc" ); // kpart-related xml file
 	setHelpMenuEnabled( false );
 
-	// KDE HACK START: Viewer fails to resize at maximized mode
-	int scnum = QApplication::desktop() ->screenNumber( parentWidget() );
-	QRect desk = QApplication::desktop() ->screenGeometry( scnum );
-	KGlobal::config() ->setGroup( "KrViewerWindow" );
-	QSize size( KGlobal::config() ->readNumEntry( QString::fromLatin1( "Width %1" ).arg( desk.width() ), 0 ),
-	            KGlobal::config() ->readNumEntry( QString::fromLatin1( "Height %1" ).arg( desk.height() ), 0 ) );
-	if ( size.width() > desk.width() )
-		KGlobal::config() ->writeEntry( QString::fromLatin1( "Width %1" ).arg( desk.width() ), desk.width() );
-	if ( size.height() > desk.height() )
-		KGlobal::config() ->writeEntry( QString::fromLatin1( "Height %1" ).arg( desk.height() ), desk.height() );
-	// KDE HACK END
-
 	setAutoSaveSettings( "KrViewerWindow", true );
 	tmpFile.setAutoDelete( true );
 
@@ -89,6 +78,9 @@ KParts::MainWindow( parent, name ), manager( this, this ), tabBar( this ) {
 //	"filesaveas"
 	setCentralWidget( &tabBar );
 
+	printAction = KStdAction::print( this, SLOT( print() ), 0, 0 );
+	copyAction = KStdAction::copy( this, SLOT( copy() ), 0, 0 );
+
 	viewerMenu = new QPopupMenu( this );
 	viewerMenu->insertItem( i18n( "&Generic viewer" ), this, SLOT( viewGeneric() ), CTRL + SHIFT + Key_G, 1 );
 	viewerMenu->insertItem( i18n( "&Text viewer" ), this, SLOT( viewText() ), CTRL + SHIFT + Key_T, 2 );
@@ -102,9 +94,12 @@ KParts::MainWindow( parent, name ), manager( this, this ), tabBar( this ) {
 	detachActionIndex = viewerMenu->insertItem( i18n( "&Detach tab" ), this, SLOT( detachTab() ), CTRL + SHIFT + Key_D );
 	//no point in detaching only one tab..
 	viewerMenu->setItemEnabled(detachActionIndex,false);	
-
-	viewerMenu->insertItem( i18n( "&Close current tab" ), this, SLOT( tabCloseRequest() ), Key_Escape );
-	viewerMenu->insertItem( i18n( "&Quit" ), this, SLOT( close() ), CTRL + Key_Q );
+	viewerMenu->insertSeparator();
+	viewerMenu->insertItem( printAction->text(), this, SLOT( print() ), printAction->shortcut() );
+	viewerMenu->insertItem( copyAction->text(), this, SLOT( copy() ), copyAction->shortcut() );
+	viewerMenu->insertSeparator();
+	tabCloseID = viewerMenu->insertItem( i18n( "&Close current tab" ), this, SLOT( tabCloseRequest() ), Key_Escape );
+	closeID = viewerMenu->insertItem( i18n( "&Quit" ), this, SLOT( close() ), CTRL + Key_Q );
 
 	//toolBar() ->insertLined("Edit:",1,"",this,"",true ,i18n("Enter an URL to edit and press enter"));
 	
@@ -119,6 +114,8 @@ KrViewer::~KrViewer() {
 	            this, SLOT( createGUI( KParts::Part* ) ) );
 
 	viewers.remove( this );
+	delete printAction;
+	delete copyAction;
 }
 
 void KrViewer::createGUI( KParts::Part* part ) {
@@ -131,17 +128,79 @@ void KrViewer::createGUI( KParts::Part* part ) {
 	         this, SLOT( slotSetStatusBarText( const QString& ) ) );
 
 	KParts::MainWindow::createGUI( part );
+	toolBar() ->insertLineSeparator(0);
+
+	PanelViewerBase *pvb = getPanelViewerBase( part );
+	if( pvb )
+		updateActions( pvb );
 
-	toolBar() ->insertSeparator(1,1);
 	toolBar() ->show();
 	statusBar() ->show();
 
+	// the KParts part may override the viewer shortcuts. We prevent it
+	// by installing an event filter on the menuBar() and the part
+	reservedKeys.clear();
+	reservedKeyIDs.clear();
+	
+	// getting the key sequences of the viewer menu
+	for( unsigned w=0; w != viewerMenu->count(); w++ )
+	{
+		int id = viewerMenu->idAt( w );
+		QKeySequence sequence = viewerMenu->accel( id );
+		if( sequence.count() > 0 )
+		{
+			reservedKeys.push_back( sequence[ 0 ] );
+			reservedKeyIDs.push_back( id );
+		}
+	}
+	
 	// and "fix" the menubar
 	menuBar() ->removeItem( 70 );
 	menuBar() ->insertItem( i18n( "&KrViewer" ), viewerMenu, 70 );
 	menuBar() ->show();
+	
+	// filtering out the key events
+	menuBar() ->installEventFilter( this );
+	part->installEventFilter( this );
 }
 
+bool KrViewer::eventFilter (  QObject * /* watched */, QEvent * e )
+{
+	if( e->type() == QEvent::AccelOverride )
+	{
+		QKeyEvent* ke = (QKeyEvent*) e;
+		if( reservedKeys.contains( ke->key() ) )
+		{
+			ke->accept();
+			
+			int id = reservedKeyIDs[ reservedKeys.findIndex( ke->key() ) ];
+			if( id != -1 )
+			{
+				// don't activate the close functions immediately!
+				// it can cause crash
+				if( id == tabCloseID )
+					QTimer::singleShot( 0, this, SLOT( tabCloseRequest() ) );
+				else if( id == closeID )
+					QTimer::singleShot( 0, this, SLOT( close() ) );
+				else {
+					int index = viewerMenu->indexOf( id );
+					viewerMenu->activateItemAt( index );
+				}
+			}
+			return true;
+		}
+	}
+	else if( e->type() == QEvent::KeyPress )
+	{
+		QKeyEvent* ke = (QKeyEvent*) e;
+		if( reservedKeys.contains( ke->key() ) )
+		{
+			ke->accept();
+			return true;
+		}
+	}
+	return false;
+}
 void KrViewer::keyPressEvent( QKeyEvent *e ) {
 	switch ( e->key() ) {
 		case Key_F10:
@@ -159,22 +218,24 @@ void KrViewer::keyPressEvent( QKeyEvent *e ) {
 KrViewer* KrViewer::getViewer(bool new_window){
 	if( !new_window ){
 		if( !viewers.first() ){	
-			viewers.prepend( new KrViewer( krApp ) ); // add to first (active)
+			viewers.prepend( new KrViewer() ); // add to first (active)
 		}
 		else {
+			if( viewers.first()->isMinimized() ) // minimized? -> show it again
+				viewers.first()->showNormal();
 			viewers.first()->raise();
 			viewers.first()->setActiveWindow();
 		}
 		return viewers.first();
 	}
 	else {
-		KrViewer *newViewer = new KrViewer( krApp );
+		KrViewer *newViewer = new KrViewer();
 		viewers.prepend( newViewer );
 		return newViewer;
 	}
 }	
 
-void KrViewer::view( KURL url ) {
+void KrViewer::view( KURL url, QWidget * parent ) {
 	Mode defaultMode = Generic;
 	bool defaultWindow = false;
 
@@ -187,22 +248,30 @@ void KrViewer::view( KURL url ) {
 	else if( modeString == "text" ) defaultMode = Text;
 	else if( modeString == "hex" ) defaultMode = Hex;
 
-	view(url,defaultMode,defaultWindow);
+	view(url,defaultMode,defaultWindow, parent );
 }
 
-void KrViewer::view( KURL url, Mode mode,  bool new_window ) {
+void KrViewer::view( KURL url, Mode mode,  bool new_window, QWidget * parent ) {
 	KrViewer* viewer = getViewer(new_window);
 
 	PanelViewerBase* viewWidget = new PanelViewer(&viewer->tabBar);
 	KParts::Part* part = viewWidget->openURL(url,mode);
-	viewer->addTab(viewWidget,"Viewing",VIEW_ICON,part);
+	viewer->addTab(viewWidget,i18n( "Viewing" ),VIEW_ICON,part);
 
-	viewer->returnFocusToKrusader = 2;
+	viewer->returnFocusTo = parent;
+	viewer->returnFocusTab = viewWidget;
 }
 
-void KrViewer::edit( KURL url, Mode mode, bool new_window ) {
+void KrViewer::edit( KURL url, QWidget * parent ) {
+	edit( url, Text, -1, parent );
+}
+
+void KrViewer::edit( KURL url, Mode mode, int new_window, QWidget * parent ) {
 	krConfig->setGroup( "General" );
 	QString edit = krConfig->readEntry( "Editor", _Editor );
+	
+	if( new_window == -1 )
+		new_window = krConfig->readBoolEntry( "View In Separate Window",_ViewInSeparateWindow );
 
 	if ( edit != "internal editor" ) {
 		KProcess proc;
@@ -220,7 +289,10 @@ void KrViewer::edit( KURL url, Mode mode, bool new_window ) {
 
 	PanelViewerBase* editWidget = new PanelEditor(&viewer->tabBar);
 	KParts::Part* part = editWidget->openURL(url,mode);
-	viewer->addTab(editWidget,QString("Editing"),EDIT_ICON,part);
+	viewer->addTab(editWidget,i18n("Editing"),EDIT_ICON,part);
+	
+	viewer->returnFocusTo = parent;
+	viewer->returnFocusTab = editWidget;
 }
 
 void KrViewer::addTab(PanelViewerBase* pvb, QString msg, QString iconName ,KParts::Part* part){
@@ -237,6 +309,8 @@ void KrViewer::addTab(PanelViewerBase* pvb, QString msg, QString iconName ,KPart
 	tabBar.setCurrentPage(tabBar.indexOf(pvb));
 	tabBar.setTabToolTip(pvb,msg+": " + url.prettyURL());
 
+	updateActions( pvb );
+
 	// now we can offer the option to detach tabs (we have more than one)
 	if( tabBar.count() > 1 ){
 		viewerMenu->setItemEnabled(detachActionIndex,true);	
@@ -250,22 +324,29 @@ void KrViewer::addTab(PanelViewerBase* pvb, QString msg, QString iconName ,KPart
 }
 
 void KrViewer::tabURLChanged( PanelViewerBase *pvb, const KURL & url ) {
-	QString msg = pvb->isEditor() ? "Editing" : "Viewing";
+	QString msg = pvb->isEditor() ? i18n( "Editing" ) : i18n( "Viewing" );
 	tabBar.setTabLabel( pvb, url.fileName()+"("+msg+")" );
 	tabBar.setTabToolTip(pvb,msg+": " + url.prettyURL());
 }
 
 void KrViewer::tabChanged(QWidget* w){
 	manager.setActivePart( static_cast<PanelViewerBase*>(w)->part() );
-	if( returnFocusToKrusader ) --returnFocusToKrusader;
-
+	
+	if( static_cast<PanelViewerBase*>(w) != returnFocusTab ) {
+		returnFocusTo = 0;
+		returnFocusTab = 0;
+	}
+	
 	// set this viewer to be the main viewer
 	if( viewers.remove( this ) ) viewers.prepend( this ); // move to first
 }
 
 void KrViewer::tabCloseRequest(QWidget *w){
 	if( !w ) return;
-
+	
+	// important to save as returnFocusTo will be cleared at removePart
+	QWidget * returnFocusToThisWidget = returnFocusTo;
+	
 	PanelViewerBase* pvb = static_cast<PanelViewerBase*>(w);
 	
 	if( !pvb->queryClose() )
@@ -278,8 +359,14 @@ void KrViewer::tabCloseRequest(QWidget *w){
 	tabBar.removePage(w);
 
 	if( tabBar.count() <= 0 ){
-		krApp->raise();
-		krApp->setActiveWindow();
+		if( returnFocusToThisWidget ){ 
+			returnFocusToThisWidget->raise();
+			returnFocusToThisWidget->setActiveWindow();
+		}
+		else {
+			krApp->raise();
+			krApp->setActiveWindow();
+		}
 		delete this;
 		return;
 	} else if( tabBar.count() == 1 ){
@@ -287,9 +374,9 @@ void KrViewer::tabCloseRequest(QWidget *w){
 		viewerMenu->setItemEnabled(detachActionIndex,false);
 	}
 
-	if( returnFocusToKrusader ){ 
-		krApp->raise();
-		krApp->setActiveWindow();
+	if( returnFocusToThisWidget ){ 
+		returnFocusToThisWidget->raise();
+		returnFocusToThisWidget->setActiveWindow();
 	}
 }
 
@@ -312,7 +399,6 @@ bool KrViewer::queryClose() {
 }
 
 bool KrViewer::queryExit() {
-	kapp->ref(); // FIX: krusader exits at closing the viewer when minimized to tray
 	return true; // don't let the reference counter reach zero
 }
 
@@ -322,7 +408,7 @@ void KrViewer::viewGeneric(){
 
 	PanelViewerBase* viewerWidget = new PanelViewer(&tabBar);
 	KParts::Part* part = viewerWidget->openURL(pvb->url(),Generic);
-	addTab(viewerWidget,QString("Viewing"),VIEW_ICON,part);
+	addTab(viewerWidget,i18n("Viewing"),VIEW_ICON,part);
 }
 
 void KrViewer::viewText(){
@@ -331,7 +417,7 @@ void KrViewer::viewText(){
 
 	PanelViewerBase* viewerWidget = new PanelViewer(&tabBar);
 	KParts::Part* part = viewerWidget->openURL(pvb->url(),Text);
-	addTab(viewerWidget,QString("Viewing"),VIEW_ICON,part);
+	addTab(viewerWidget,i18n("Viewing"),VIEW_ICON,part);
 }
 
 void KrViewer::viewHex(){
@@ -340,7 +426,7 @@ void KrViewer::viewHex(){
 
 	PanelViewerBase* viewerWidget = new PanelViewer(&tabBar);
 	KParts::Part* part = viewerWidget->openURL(pvb->url(),Hex);
-	addTab(viewerWidget,QString("Viewing"),VIEW_ICON,part);
+	addTab(viewerWidget,i18n("Viewing"),VIEW_ICON,part);
 }
 
 void KrViewer::editText(){
@@ -349,7 +435,7 @@ void KrViewer::editText(){
 
 	PanelViewerBase* editWidget = new PanelEditor(&tabBar);
 	KParts::Part* part = editWidget->openURL(pvb->url(),Text);
-	addTab(editWidget,QString("Editing"),EDIT_ICON,part);
+	addTab(editWidget,i18n("Editing"),EDIT_ICON,part);
 }
 
 void KrViewer::checkModified(){
@@ -365,9 +451,8 @@ void KrViewer::checkModified(){
 	// add a * to modified files.
 	if( pvb->isModified() ){
 		QString label = tabBar.tabLabel(pvb);
-		if( !label.endsWith("*)") ){
-			label.truncate(label.length()-1);
-			label.append("*)");
+		if( !label.startsWith("*" + pvb->part()->url().fileName() ) ){
+			label.prepend("*");
 			QIconSet icon = QIconSet(krLoader->loadIcon(MODIFIED_ICON,KIcon::Small));
 
 			tabBar.changeTab(pvb,icon,label);
@@ -376,9 +461,8 @@ void KrViewer::checkModified(){
 	// remove the * from previously modified files.
 	else {
 		QString label = tabBar.tabLabel(pvb);
-		if( label.endsWith("*)") ){
-			label.truncate(label.length()-2);
-			label.append(")");
+		if( label.startsWith("*" + pvb->part()->url().fileName() ) ){
+			label = label.mid( 1 );
 			QIconSet icon = QIconSet(krLoader->loadIcon(EDIT_ICON,KIcon::Small));
 
 			tabBar.changeTab(pvb,icon,label);
@@ -413,14 +497,57 @@ void KrViewer::detachTab(){
 	
 	pvb->reparent(&viewer->tabBar,QPoint(0,0));
 
-	viewer->addTab(pvb,"Viewing",VIEW_ICON,pvb->part());
+	if( pvb->isEditor() )
+		viewer->addTab(pvb,i18n( "Editing" ),EDIT_ICON,pvb->part());
+	else
+		viewer->addTab(pvb,i18n( "Viewing" ),VIEW_ICON,pvb->part());
 }
 
-void KrViewer::windowActivationChange ( bool oldActive ) {
+void KrViewer::windowActivationChange ( bool /* oldActive */ ) {
 	if( isActiveWindow() )
 		if( viewers.remove( this ) ) viewers.prepend( this ); // move to first
 }
 
+void KrViewer::print() {
+	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentPage() );
+	if( !pvb ) return;
+	
+	KParts::BrowserExtension * ext = KParts::BrowserExtension::childObject( pvb->part() );
+	if( ext && ext->isActionEnabled( "print" ) )
+		Invoker( ext, SLOT( print() ) ).invoke();
+}
+
+void KrViewer::copy() {
+	PanelViewerBase* pvb = static_cast<PanelViewerBase*>( tabBar.currentPage() );
+	if( !pvb ) return;
+	
+	KParts::BrowserExtension * ext = KParts::BrowserExtension::childObject( pvb->part() );
+	if( ext && ext->isActionEnabled( "copy" ) )
+		Invoker( ext, SLOT( copy() ) ).invoke();
+}
+
+PanelViewerBase * KrViewer::getPanelViewerBase( KParts::Part * part ) {
+	for( int i=0; i != tabBar.count(); i++ ) {
+		PanelViewerBase *pvb = static_cast<PanelViewerBase*>( tabBar.page( i ) );
+		if( pvb && pvb->part() == part )
+			return pvb;
+	}
+	return 0;
+}
+
+void KrViewer::updateActions( PanelViewerBase * pvb ) {
+	if( pvb->isEditor() ) {
+		printAction->unplugAll();
+		copyAction->unplugAll();
+	}
+	else {
+		if( !printAction->isPlugged( toolBar() ) )
+			printAction->plug( toolBar(), 0 );
+		if( !copyAction->isPlugged( toolBar() ) )
+			copyAction->plug( toolBar(), 1 );
+	}
+}
+
 #if 0
 bool KrViewer::editGeneric( QString mimetype, KURL _url ) {
 	KParts::ReadWritePart * kedit_part = 0L;
