@@ -45,7 +45,6 @@ KgArchives::KgArchives( bool first, QWidget* parent,  const char* name ) :
 {
   QGridLayout *kgArchivesLayout = new QGridLayout( parent );
   kgArchivesLayout->setSpacing( 6 );
-  kgArchivesLayout->setMargin( 11 );
 
   //  -------------------------- GENERAL GROUPBOX ----------------------------------
 
@@ -66,10 +65,11 @@ KgArchives::KgArchives( bool first, QWidget* parent,  const char* name ) :
      {"Archives","Do RPM",   _DoRPM,   i18n( "Rpm" ),   false,  ""},
      {"Archives","Do UnAce", _DoUnAce, i18n( "Ace" ),   false,  ""},
      {"Archives","Do Lha",   _DoLha,   i18n( "Lha" ),   false,  ""},
-     {"Archives","Do DEB",   _DoDEB,   i18n( "Deb" ),   false,  ""}
+     {"Archives","Do DEB",   _DoDEB,   i18n( "Deb" ),   false,  ""},
+     {"Archives","Do 7z",    _Do7z,    i18n( "7zip" ),  false,  ""}
     };
 
-  cbs = createCheckBoxGroup( 3, 0, packers, 10, generalGrp );
+  cbs = createCheckBoxGroup( 3, 0, packers, 11, generalGrp );
   generalGrid->addWidget( cbs, 1, 0 );
 
   addLabel( generalGrid, 2, 0, i18n( "The archives that are \"greyed-out\" were unavailable on your\nsystem last time Krusader checked. If you wish Krusader to\nsearch again, click the 'Auto Configure' button." ),
@@ -132,6 +132,7 @@ void KgArchives::disableNonExistingPackers()
   cbs->find( "Do UnAce" )->setEnabled(PS("unace"));
   cbs->find( "Do Unarj" )->setEnabled(PS("unarj") || PS("arj") );
   cbs->find( "Do DEB" )->setEnabled(PS("dpkg") && PS("tar") );
+  cbs->find( "Do 7z" )->setEnabled( PS("7z") );
 
   krConfig->setGroup( "Archives" );
   krConfig->writeEntry( "Supported Packers", lst );
