@@ -45,7 +45,6 @@ KgColors::KgColors( bool first, QWidget* parent,  const char* name ) :
 {
   QGridLayout *kgColorsLayout = new QGridLayout( parent );
   kgColorsLayout->setSpacing( 6 );
-  kgColorsLayout->setMargin( 5 );
 
   //  -------------------------- GENERAL GROUPBOX ----------------------------------
 
@@ -56,10 +55,11 @@ KgColors::KgColors( bool first, QWidget* parent,  const char* name ) :
   generalGrid->setMargin( 5 );
 
   KONFIGURATOR_CHECKBOX_PARAM generalSettings[] =
-  //  cfg_class  cfg_name                     default               text                                      restart tooltip
-    {{"Colors","KDE Default",                 _KDEDefaultColors,    i18n( "Use the default KDE colors" ),     false,  "<p><img src='toolbar|kcontrol'></p>" + i18n( "Use KDE's global color configuration.<p><i>KDE Control Center -> Appearance & Themes -> Colors</i>") },
-     {"Colors","Enable Alternate Background", _AlternateBackground, i18n( "Use alternate background color" ),  false, i18n( "The <b>background color</b> and the <b>alternate background</b> color alternates line by line.<p>When you don't use the <i>KDE default colors</i>, you can configure the alternate colors in the <i>colors</i> box.") },
-     {"Colors","Show Current Item Always", _ShowCurrentItemAlways, i18n( "Show current item even if not focused" ),  false, i18n( "Shows the last cursor position in the non active list panel.<p>This option is only available when you don't use the <i>KDE default colors</i>." ) }};
+  //  cfg_class  cfg_name                     default                 text                                              restart tooltip
+    {{"Colors","KDE Default",                 _KDEDefaultColors,      i18n( "Use the default KDE colors" ),             false,  "<p><img src='toolbar|kcontrol'></p>" + i18n( "<p>Use KDE's global color configuration.</p><p><i>KDE Control Center -> Appearance & Themes -> Colors</i></p>") },
+     {"Colors","Enable Alternate Background", _AlternateBackground,   i18n( "Use alternate background color" ),         false, i18n( "<p>The <b>background color</b> and the <b>alternate background</b> color alternates line by line.</p><p>When you don't use the <i>KDE default colors</i>, you can configure the alternate colors in the <i>colors</i> box.</p>") },
+     {"Colors","Show Current Item Always",    _ShowCurrentItemAlways, i18n( "Show current item even if not focused" ),  false, i18n( "<p>Shows the last cursor position in the non active list panel.</p><p>This option is only available when you don't use the <i>KDE default colors</i>.</p>" ) },
+     {"Colors","Dim Inactive Colors",         _DimInactiveColors,     i18n( "Dim the colors of the inactive panel" ),   false, i18n( "<p>The colors of the inactive panel are calculated by a dim color and a dim factor.</p>" ) }};
 
   generals = createCheckBoxGroup( 0, 2, generalSettings, sizeof(generalSettings)/sizeof(generalSettings[0]), generalGrp );
   generalGrid->addWidget( generals, 1, 0 );
@@ -69,6 +69,7 @@ KgColors::KgColors( bool first, QWidget* parent,  const char* name ) :
   connect( generals->find( "KDE Default" ), SIGNAL( stateChanged( int ) ), this, SLOT( slotDisable() ) );
   connect( generals->find( "Enable Alternate Background" ), SIGNAL( stateChanged( int ) ), this, SLOT( generatePreview() ) );
   connect( generals->find( "Show Current Item Always" ), SIGNAL( stateChanged( int ) ), this, SLOT( slotDisable() ) );
+  connect( generals->find( "Dim Inactive Colors" ), SIGNAL( stateChanged( int ) ), this, SLOT( slotDisable() ) );
 
   kgColorsLayout->addMultiCellWidget( generalGrp, 0 ,0, 0, 2 );
   QHBox *hbox = new QHBox( parent );
@@ -101,13 +102,13 @@ KgColors::KgColors( bool first, QWidget* parent,  const char* name ) :
   addColorSelector( "Background",                 i18n( "Background:" ),                  KGlobalSettings::baseColor()                                                );
   ADDITIONAL_COLOR sameAsBckgnd = { i18n("Same as background"), getColorSelector( "Background" )->getColor(), "Background" };
   addColorSelector( "Alternate Background",       i18n( "Alternate background:" ),        KGlobalSettings::alternateBackgroundColor(),"", &sameAsBckgnd, 1            );
-  addColorSelector( "Marked Foreground",          i18n( "Marked foreground:" ),           KGlobalSettings::highlightedTextColor(), "", &transparent, 1                );
-  addColorSelector( "Marked Background",          i18n( "Marked background:" ),           KGlobalSettings::highlightColor(), "", &sameAsBckgnd, 1                     );
+  addColorSelector( "Marked Foreground",          i18n( "Selected foreground:" ),           KGlobalSettings::highlightedTextColor(), "", &transparent, 1                );
+  addColorSelector( "Marked Background",          i18n( "Selected background:" ),           KGlobalSettings::highlightColor(), "", &sameAsBckgnd, 1                     );
   ADDITIONAL_COLOR sameAsAltern = { i18n("Same as alt. background"), getColorSelector( "Alternate Background" )->getColor(), "Alternate Background" };
-  addColorSelector( "Alternate Marked Background",i18n( "Alternate marked background:" ), getColorSelector( "Marked Background" )->getColor(), i18n( "Same as marked background" ), &sameAsAltern, 1 );
+  addColorSelector( "Alternate Marked Background",i18n( "Alternate selected background:" ), getColorSelector( "Marked Background" )->getColor(), i18n( "Same as selected background" ), &sameAsAltern, 1 );
   addColorSelector( "Current Foreground",         i18n( "Current foreground:" ),          Qt::white,                                    i18n( "Not used" )            );
-  ADDITIONAL_COLOR sameAsMarkedForegnd = { i18n("Same as marked foreground"), getColorSelector( "Marked Foreground" )->getColor(), "Marked Foreground" };
-  addColorSelector( "Marked Current Foreground",         i18n( "Marked current foreground:" ),          Qt::white,                                    i18n( "Not used" ), &sameAsMarkedForegnd, 1);
+  ADDITIONAL_COLOR sameAsMarkedForegnd = { i18n("Same as selected foreground"), getColorSelector( "Marked Foreground" )->getColor(), "Marked Foreground" };
+  addColorSelector( "Marked Current Foreground",         i18n( "Selected current foreground:" ),          Qt::white,                                    i18n( "Not used" ), &sameAsMarkedForegnd, 1);
   addColorSelector( "Current Background",         i18n( "Current background:" ),          Qt::white, i18n( "Not used" ), &sameAsBckgnd, 1                             );
 
   colorsGrid->addWidget(createSpacer(colorsGrp, ""), itemList.count() - offset, 1);
@@ -117,10 +118,12 @@ KgColors::KgColors( bool first, QWidget* parent,  const char* name ) :
   connect( getColorSelector( "Alternate Background" ), SIGNAL( colorChanged() ), this, SLOT( slotAltBackgroundChanged() ) );
   connect( getColorSelector( "Marked Background" ), SIGNAL( colorChanged() ), this, SLOT( slotMarkedBackgroundChanged() ) );
 
-  colorsGrp = new QWidget( colorTabWidget, "colorTab2" );
-  colorTabWidget->insertTab( colorsGrp, i18n( "Inactive" ) );
+  inactiveColorStack = new QWidgetStack( colorTabWidget, "colorTab2" );
+  colorTabWidget->insertTab( inactiveColorStack, i18n( "Inactive" ) );
 
-  colorsGrid = new QGridLayout( colorsGrp );
+  colorsGrp = normalInactiveWidget = new QWidget( inactiveColorStack, "colorTab2" );
+
+  colorsGrid = new QGridLayout( normalInactiveWidget );
   colorsGrid->setSpacing( 0 );
   colorsGrid->setMargin( 2 );
 
@@ -135,23 +138,48 @@ KgColors::KgColors( bool first, QWidget* parent,  const char* name ) :
   addColorSelector( "Inactive Background",                  i18n( "Background:" ),                  getColorSelector( "Background" )->getColor(), i18n( "Same as active" ) );
   ADDITIONAL_COLOR sameAsInactBckgnd = { i18n("Same as background"), getColorSelector( "Inactive Background" )->getColor(), "Inactive Background" };
   addColorSelector( "Inactive Alternate Background",        i18n( "Alternate background:" ),        getColorSelector( "Alternate Background" )->getColor(), i18n( "Same as active" ), &sameAsInactBckgnd, 1 );
-  addColorSelector( "Inactive Marked Foreground",           i18n( "Marked foreground:" ),           getColorSelector( "Marked Foreground" )->getColor(), i18n( "Same as active" ), &transparent, 1 );
-  addColorSelector( "Inactive Marked Background",           i18n( "Marked background:" ),           getColorSelector( "Marked Background" )->getColor(), i18n( "Same as active" ), &sameAsInactBckgnd, 1 );
+  addColorSelector( "Inactive Marked Foreground",           i18n( "Selected foreground:" ),           getColorSelector( "Marked Foreground" )->getColor(), i18n( "Same as active" ), &transparent, 1 );
+  addColorSelector( "Inactive Marked Background",           i18n( "Selected background:" ),           getColorSelector( "Marked Background" )->getColor(), i18n( "Same as active" ), &sameAsInactBckgnd, 1 );
   ADDITIONAL_COLOR sameAsInactAltern[] = {{ i18n("Same as alt. background"), getColorSelector( "Inactive Alternate Background" )->getColor(), "Inactive Alternate Background" },
-                                          { i18n("Same as marked background"), getColorSelector( "Inactive Marked Background" )->getColor(), "Inactive Marked Background" } };
-  addColorSelector( "Inactive Alternate Marked Background", i18n( "Alternate marked background:" ), getColorSelector( "Alternate Marked Background" )->getColor(), i18n( "Same as active" ), sameAsInactAltern, 2 );
+                                          { i18n("Same as selected background"), getColorSelector( "Inactive Marked Background" )->getColor(), "Inactive Marked Background" } };
+  addColorSelector( "Inactive Alternate Marked Background", i18n( "Alternate selected background:" ), getColorSelector( "Alternate Marked Background" )->getColor(), i18n( "Same as active" ), sameAsInactAltern, 2 );
   addColorSelector( "Inactive Current Foreground",          i18n( "Current foreground:" ),          getColorSelector( "Current Foreground" )->getColor(), i18n( "Same as active" ) );
-  ADDITIONAL_COLOR sameAsInactMarkedForegnd = { i18n("Same as marked foreground"), getColorSelector( "Inactive Marked Foreground" )->getColor(), "Inactive Marked Foreground" };
-  addColorSelector( "Inactive Marked Current Foreground",          i18n( "Marked current foreground:" ),          getColorSelector( "Marked Current Foreground" )->getColor(), i18n( "Same as active" ), &sameAsInactMarkedForegnd, 1 );
+  ADDITIONAL_COLOR sameAsInactMarkedForegnd = { i18n("Same as selected foreground"), getColorSelector( "Inactive Marked Foreground" )->getColor(), "Inactive Marked Foreground" };
+  addColorSelector( "Inactive Marked Current Foreground",          i18n( "Selected current foreground:" ),          getColorSelector( "Marked Current Foreground" )->getColor(), i18n( "Same as active" ), &sameAsInactMarkedForegnd, 1 );
   addColorSelector( "Inactive Current Background",          i18n( "Current background:" ),          getColorSelector( "Current Background" )->getColor(), i18n( "Same as active" ), &sameAsInactBckgnd, 1 );
 
-  colorsGrid->addWidget(createSpacer(colorsGrp, ""), itemList.count() - offset, 1);
+  colorsGrid->addWidget(createSpacer(normalInactiveWidget, ""), itemList.count() - offset, 1);
 
   connect( getColorSelector( "Inactive Foreground" ), SIGNAL( colorChanged() ), this, SLOT( slotInactiveForegroundChanged() ) );
   connect( getColorSelector( "Inactive Background" ), SIGNAL( colorChanged() ), this, SLOT( slotInactiveBackgroundChanged() ) );
   connect( getColorSelector( "Inactive Alternate Background" ), SIGNAL( colorChanged() ), this, SLOT( slotInactiveAltBackgroundChanged() ) );
   connect( getColorSelector( "Inactive Marked Background" ), SIGNAL( colorChanged() ), this, SLOT( slotInactiveMarkedBackgroundChanged() ) );
 
+  offset = endOfPanelColors = itemList.count();
+
+  inactiveColorStack->addWidget( normalInactiveWidget );
+
+  colorsGrp = dimmedInactiveWidget = new QWidget( inactiveColorStack, "colorTab2dimmed" );
+
+  colorsGrid = new QGridLayout( dimmedInactiveWidget );
+  colorsGrid->setSpacing( 0 );
+  colorsGrid->setMargin( 2 );
+
+  addColorSelector( "Dim Target Color", i18n( "Dim target color:" ), Qt::white);
+
+  int index = itemList.count() - offset;
+  labelList.append( addLabel( colorsGrid, index, 0, i18n("Dim factor:"), colorsGrp, QString( "ColorsLabel%1" ).arg( index ).ascii() ) );
+  dimFactor = createSpinBox("Colors", "Dim Factor", 100, 0, 100, colorsGrp);
+  dimFactor->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed );
+  connect( dimFactor, SIGNAL( valueChanged( int ) ), this, SLOT( generatePreview() ) );
+  colorsGrid->addWidget( dimFactor, index++, 1 );
+
+  colorsGrid->addWidget(createSpacer(dimmedInactiveWidget, ""), itemList.count() + 1 - offset, 1);
+
+  inactiveColorStack->addWidget( dimmedInactiveWidget );
+
+  inactiveColorStack->raiseWidget( normalInactiveWidget );
+
   colorsGrp = new QWidget( colorTabWidget, "colorTab3" );
   colorTabWidget->insertTab( colorsGrp, i18n( "Synchronizer" ) );
 
@@ -271,6 +299,13 @@ void KgColors::slotDisable()
 
   generals->find("Enable Alternate Background")->setEnabled( enabled );
   generals->find("Show Current Item Always")->setEnabled( !enabled );
+  generals->find("Dim Inactive Colors")->setEnabled( !enabled );
+
+  bool dimmed = !enabled && generals->find("Dim Inactive Colors")->isChecked();
+  if( dimmed )
+    inactiveColorStack->raiseWidget( dimmedInactiveWidget );
+  else
+    inactiveColorStack->raiseWidget( normalInactiveWidget );
 
   enabled = enabled || !generals->find( "Show Current Item Always" )->isChecked();
 
@@ -348,6 +383,23 @@ void KgColors::slotInactiveMarkedBackgroundChanged()
   getColorSelector( "Inactive Alternate Marked Background" )->changeAdditionalColor( 1, color );
 }
 
+void KgColors::setColorWithDimming(PreviewItem * item, QColor foreground, QColor background, bool dimmed )
+{
+   if ( dimmed && dimFactor->value() < 100)
+   {
+     int dim = dimFactor->value();
+     QColor dimColor = getColorSelector("Dim Target Color")->getColor();
+
+     foreground = QColor((dimColor.red() * (100 - dim) + foreground.red() * dim) / 100,
+                         (dimColor.green() * (100 - dim) + foreground.green() * dim) / 100,
+                         (dimColor.blue() * (100 - dim) + foreground.blue() * dim) / 100);
+     background = QColor((dimColor.red() * (100 - dim) + background.red() * dim) / 100,
+                         (dimColor.green() * (100 - dim) + background.green() * dim) / 100,
+                         (dimColor.blue() * (100 - dim) + background.blue() * dim) / 100);
+   }
+   item->setColor(foreground, background);
+}
+
 void KgColors::generatePreview()
 {
   int currentPage = colorTabWidget->currentPageIndex();
@@ -356,8 +408,9 @@ void KgColors::generatePreview()
 
   if( currentPage == 0 || currentPage == 1 )
   {
-    PreviewItem *pwMark2   = new PreviewItem( preview, i18n( "Marked 2" ) );
-    PreviewItem *pwMark1   = new PreviewItem( preview, i18n( "Marked 1" ) );
+    PreviewItem *pwMarkCur = new PreviewItem( preview, i18n( "Selected + Current" ) );
+    PreviewItem *pwMark2   = new PreviewItem( preview, i18n( "Selected 2" ) );
+    PreviewItem *pwMark1   = new PreviewItem( preview, i18n( "Selected 1" ) );
     PreviewItem *pwCurrent = new PreviewItem( preview, i18n( "Current" ) );
     PreviewItem *pwInvLink = new PreviewItem( preview, i18n( "Invalid symlink" ) );
     PreviewItem *pwSymLink = new PreviewItem( preview, i18n( "Symbolic link" ) );
@@ -365,83 +418,57 @@ void KgColors::generatePreview()
     PreviewItem *pwFile    = new PreviewItem( preview, i18n( "File" ) );
     PreviewItem *pwDir     = new PreviewItem( preview, i18n( "Directory" ) );
 
-    if( generals->find( "KDE Default" )->isChecked() )
+    bool isActive = currentPage == 0;
+
+    // create local color cache instance, which does NOT affect the color cache instance using to paint the panels
+    KrColorCache colCache;
+
+    // create local color settings instance, which initially contains the setings from krConfig
+    KrColorSettings colorSettings;
+
+    // copy over local settings to color settings instance, which does not affect the persisted krConfig settings
+    QValueList<QString> names = KrColorSettings::getColorNames();
+    for ( QStringList::Iterator it = names.begin(); it != names.end(); ++it )
     {
-      QColor bck    = KGlobalSettings::baseColor();
-      QColor altBck = KGlobalSettings::alternateBackgroundColor();
-      if( !generals->find("Enable Alternate Background")->isChecked() )
-        altBck = bck;
-      QColor fore   = KGlobalSettings::textColor();
-
-      pwFile->setColor( fore, altBck );
-      pwDir->setColor( fore, bck );
-      pwApp->setColor( fore, bck );
-      pwSymLink->setColor( fore, altBck );
-      pwInvLink->setColor( fore, bck );
-      pwCurrent->setColor( fore, altBck );
-      pwMark1->setColor( KGlobalSettings::highlightedTextColor(), KGlobalSettings::highlightColor() );
-      pwMark2->setColor( KGlobalSettings::highlightedTextColor(), KGlobalSettings::highlightColor() );
+        KonfiguratorColorChooser * chooser = getColorSelector( *it );
+        if (!chooser)
+            continue;
+        colorSettings.setColorTextValue( *it, chooser->getValue());
+        if (chooser->isValueRGB())
+            colorSettings.setColorValue( *it, chooser->getColor());
+        else
+            colorSettings.setColorValue( *it, QColor());
     }
-    else
-    {
-      bool isInactive = currentPage == 1;
-      QString prefix="";
 
-      if( isInactive )
-        prefix = "Inactive ";
+    colorSettings.setBoolValue("KDE Default", generals->find( "KDE Default" )->isChecked());
+    colorSettings.setBoolValue("Enable Alternate Background", generals->find( "Enable Alternate Background" )->isChecked());
+    colorSettings.setBoolValue("Show Current Item Always", generals->find( "Show Current Item Always" )->isChecked());
+    colorSettings.setBoolValue("Dim Inactive Colors", generals->find( "Dim Inactive Colors" )->isChecked());
+    colorSettings.setNumValue("Dim Factor", dimFactor->value());
 
-      QColor  bck   = getColorSelector( prefix + "Background" )->getColor();
-      QColor altBck = getColorSelector( prefix + "Alternate Background" )->getColor();
+    // let the color cache use the local color settings
+    colCache.setColors( colorSettings );
 
-      QColor currentFore;
-      QColor currentBck = altBck;
-
-      pwFile->setColor( currentFore = getColorSelector( prefix + "Foreground" )->getColor(), altBck );
-      pwDir->setColor( getColorSelector( prefix + "Directory Foreground" )->getColor(), bck );
-      pwApp->setColor( getColorSelector( prefix + "Executable Foreground" )->getColor(), bck );
-      pwSymLink->setColor( getColorSelector( prefix + "Symlink Foreground" )->getColor(), altBck );
-      pwInvLink->setColor( getColorSelector( prefix + "Invalid Symlink Foreground" )->getColor(), bck );
-
-      if( isInactive )
-      {
-        if( generals->find( "Show Current Item Always" )->isChecked() )
-        {
-          if( getColorSelector( "Inactive Current Foreground" )->currentItem() != 1 )
-            currentFore = getColorSelector( "Inactive Current Foreground" )->getColor();
-          else
-          {
-            if( getColorSelector( "Current Foreground" )->currentItem() != 1 )
-              currentFore = getColorSelector( "Current Foreground" )->getColor();
-          }
-          if( getColorSelector( "Inactive Current Background" )->currentItem() != 1 )
-            currentBck = getColorSelector( "Inactive Current Background" )->getColor();
-          else
-          {
-            if( getColorSelector( "Current Background" )->currentItem() != 1 )
-              currentBck = getColorSelector( "Current Background" )->getColor();
-          }
-        }
-      }
-      else
-      {
-        if( getColorSelector( "Current Background" )->currentItem() != 1 )
-          currentBck = getColorSelector( "Current Background" )->getColor();
-        if( getColorSelector( "Current Foreground" )->currentItem() != 1 )
-          currentFore = getColorSelector( "Current Foreground" )->getColor();
-        else currentFore = setColorIfContrastIsSufficient(currentBck, getColorSelector( prefix + "Foreground" )->getColor(), bck);
-      }
-
-      pwCurrent->setColor( currentFore, currentBck );
-
-      QColor markFore = getColorSelector( prefix + "Marked Foreground" )->getColor();
-
-      if( !isInactive || getColorSelector( "Inactive Marked Foreground" )->currentItem() == 1 )
-        if( getColorSelector( "Marked Foreground" )->currentItem() == 2 )
-          markFore = currentFore;
-
-      pwMark1->setColor( markFore, getColorSelector( prefix + "Marked Background" )->getColor() );
-      pwMark2->setColor( markFore, getColorSelector( prefix + "Alternate Marked Background" )->getColor() );
-    }
+    // ask the local color cache for certain color groups and use them to color the preview
+    QColorGroup cg;
+    colCache.getColors(cg, KrColorItemType(KrColorItemType::Directory, false, isActive, false, false));
+    pwDir->setColor( cg.text(), cg.background() );
+    colCache.getColors(cg, KrColorItemType(KrColorItemType::File, true, isActive, false, false));
+    pwFile->setColor( cg.text(), cg.background() );
+    colCache.getColors(cg, KrColorItemType(KrColorItemType::Executable, false, isActive, false, false));
+    pwApp->setColor( cg.text(), cg.background() );
+    colCache.getColors(cg, KrColorItemType(KrColorItemType::Symlink, true, isActive, false, false));
+    pwSymLink->setColor( cg.text(), cg.background() );
+    colCache.getColors(cg, KrColorItemType(KrColorItemType::InvalidSymlink, false, isActive, false, false));
+    pwInvLink->setColor( cg.text(), cg.background() );
+    colCache.getColors(cg, KrColorItemType(KrColorItemType::File, true, isActive, true, false));
+    pwCurrent->setColor( cg.highlightedText(), cg.highlight() );
+    colCache.getColors(cg, KrColorItemType(KrColorItemType::File, false, isActive, false, true));
+    pwMark1->setColor( cg.highlightedText(), cg.highlight() );
+    colCache.getColors(cg, KrColorItemType(KrColorItemType::File, true, isActive, false, true));
+    pwMark2->setColor( cg.highlightedText(), cg.highlight() );
+    colCache.getColors(cg, KrColorItemType(KrColorItemType::File, false, isActive, true, true));
+    pwMarkCur->setColor( cg.highlightedText(), cg.highlight() );
   }else if( currentPage == 2 )
   {
     PreviewItem *pwDelete    = new PreviewItem( preview, i18n( "Delete" ) );
@@ -463,17 +490,6 @@ void KgColors::generatePreview()
   }
 }
 
-const QColor & KgColors::setColorIfContrastIsSufficient(const QColor & background, const QColor & color1, const QColor & color2)
-{
-   #define sqr(x) ((x)*(x))
-   int contrast = sqr(color1.red() - background.red()) + sqr(color1.green() - background.green()) + sqr(color1.blue() - background.blue());
-
-   // if the contrast between background and color1 is too small, take color2 instead.
-   if (contrast < 1000)
-      return color2;
-   return color1;
-}
-
 bool KgColors::apply()
 {
   bool result = KonfiguratorPage::apply();
@@ -539,6 +555,9 @@ void KgColors::serialize(QDataStream & stream)
    serializeItem(stream, "Inactive Executable Foreground");
    serializeItem(stream, "Inactive Symlink Foreground");
    serializeItem(stream, "Inactive Invalid Symlink Foreground");
+   serializeItem(stream, "Dim Inactive Colors");
+   serializeItem(stream, "Dim Target Color");
+   serializeItem(stream, "Dim Factor");
    serializeItem(stream, "KDE Default");
    serializeItem(stream, "Marked Background");
    serializeItem(stream, "Marked Current Foreground");
@@ -566,7 +585,8 @@ void KgColors::deserialize(QDataStream & stream)
       if (name == "")
          break;
 
-      if (name == "KDE Default" || name == "Enable Alternate Background" || name == "Show Current Item Always" )
+      if (name == "KDE Default" || name == "Enable Alternate Background" ||
+          name == "Show Current Item Always" || name == "Dim Inactive Colors" )
       {
         bool bValue = false;
         value = value.lower();
@@ -576,6 +596,13 @@ void KgColors::deserialize(QDataStream & stream)
         generals->find( name )->setChecked( bValue );
         continue;
       }
+
+      if( name == "Dim Factor" )
+      {
+        dimFactor->setValue( value.toInt() );
+        continue;
+      }
+
       KonfiguratorColorChooser *selector = getColorSelector( name );
       if( selector == 0 )
         break;
@@ -586,11 +613,14 @@ void KgColors::deserialize(QDataStream & stream)
 void KgColors::serializeItem(class QDataStream & stream, const char * name)
 {
    stream << QString(name);
-   if( name == "KDE Default" || name == "Enable Alternate Background" || name == "Show Current Item Always" )
+   if( name == "KDE Default" || name == "Enable Alternate Background" ||
+       name == "Show Current Item Always" || name == "Dim Inactive Colors" )
    {
      bool bValue = generals->find( name )->isChecked();
      stream << QString( bValue ? "true" : "false" );
    }
+   else if( name == "Dim Factor" )
+     stream << QString::number(dimFactor->value());
    else
    {
      KonfiguratorColorChooser *selector = getColorSelector( name );
