@@ -45,7 +45,6 @@ KgDependencies::KgDependencies( bool first, QWidget* parent,  const char* name )
 {
   QGridLayout *kgDependenciesLayout = new QGridLayout( parent );
   kgDependenciesLayout->setSpacing( 6 );
-  kgDependenciesLayout->setMargin( 11 );
 
   //  ---------------------------- GENERAL TAB -------------------------------------
   tabWidget = new QTabWidget( parent, "tabWidget" );
@@ -80,19 +79,20 @@ KgDependencies::KgDependencies( bool first, QWidget* parent,  const char* name )
   archGrid1->setMargin( 11 );
   archGrid1->setAlignment( Qt::AlignTop );
 
-  addApplication( "arj",   archGrid1, 0, packers_tab, PAGE_PACKERS );
-  addApplication( "bzip2", archGrid1, 1, packers_tab, PAGE_PACKERS );
-  addApplication( "cpio",  archGrid1, 2, packers_tab, PAGE_PACKERS );
-  addApplication( "dpkg",  archGrid1, 3, packers_tab, PAGE_PACKERS );
-  addApplication( "gzip",  archGrid1, 4, packers_tab, PAGE_PACKERS );
-  addApplication( "lha",   archGrid1, 5, packers_tab, PAGE_PACKERS );
-  addApplication( "rar",   archGrid1, 6, packers_tab, PAGE_PACKERS );
-  addApplication( "tar",   archGrid1, 7, packers_tab, PAGE_PACKERS );
-  addApplication( "unace", archGrid1, 8, packers_tab, PAGE_PACKERS );
-  addApplication( "unarj", archGrid1, 9, packers_tab, PAGE_PACKERS );
-  addApplication( "unrar", archGrid1,10, packers_tab, PAGE_PACKERS );
-  addApplication( "unzip", archGrid1,11, packers_tab, PAGE_PACKERS );
-  addApplication( "zip",   archGrid1,12, packers_tab, PAGE_PACKERS );
+  addApplication( "7z",    archGrid1, 0, packers_tab, PAGE_PACKERS, "7za" );
+  addApplication( "arj",   archGrid1, 1, packers_tab, PAGE_PACKERS );
+  addApplication( "bzip2", archGrid1, 2, packers_tab, PAGE_PACKERS );
+  addApplication( "cpio",  archGrid1, 3, packers_tab, PAGE_PACKERS );
+  addApplication( "dpkg",  archGrid1, 4, packers_tab, PAGE_PACKERS );
+  addApplication( "gzip",  archGrid1, 5, packers_tab, PAGE_PACKERS );
+  addApplication( "lha",   archGrid1, 6, packers_tab, PAGE_PACKERS );
+  addApplication( "rar",   archGrid1, 7, packers_tab, PAGE_PACKERS );
+  addApplication( "tar",   archGrid1, 8, packers_tab, PAGE_PACKERS );
+  addApplication( "unace", archGrid1, 9, packers_tab, PAGE_PACKERS );
+  addApplication( "unarj", archGrid1,10, packers_tab, PAGE_PACKERS );
+  addApplication( "unrar", archGrid1,11, packers_tab, PAGE_PACKERS );
+  addApplication( "unzip", archGrid1,12, packers_tab, PAGE_PACKERS );
+  addApplication( "zip",   archGrid1,13, packers_tab, PAGE_PACKERS );
 
   //  ---------------------------- CHECKSUM TAB -------------------------------------
   QWidget *checksum_tab = new QWidget( tabWidget, "tab_4" );
@@ -105,19 +105,33 @@ KgDependencies::KgDependencies( bool first, QWidget* parent,  const char* name )
 
   addApplication( "md5sum",         archGrid2, 0, checksum_tab, PAGE_CHECKSUM );
   addApplication( "sha1sum",        archGrid2, 1, checksum_tab, PAGE_CHECKSUM );
-  addApplication( "md5deep",        archGrid2, 2, checksum_tab, PAGE_CHECKSUM );
-  addApplication( "sha1deep",       archGrid2, 3, checksum_tab, PAGE_CHECKSUM );
-  addApplication( "sha256deep",     archGrid2, 4, checksum_tab, PAGE_CHECKSUM );
-  addApplication( "tigerdeep",      archGrid2, 5, checksum_tab, PAGE_CHECKSUM );
-  addApplication( "whirlpooldeep",  archGrid2, 6, checksum_tab, PAGE_CHECKSUM );
-  addApplication( "cfv",            archGrid2, 7, checksum_tab, PAGE_CHECKSUM );
+  addApplication( "sha224sum",      archGrid2, 2, checksum_tab, PAGE_CHECKSUM );
+  addApplication( "sha256sum",      archGrid2, 3, checksum_tab, PAGE_CHECKSUM );
+  addApplication( "sha384sum",      archGrid2, 4, checksum_tab, PAGE_CHECKSUM );
+  addApplication( "sha512sum",      archGrid2, 5, checksum_tab, PAGE_CHECKSUM );
+  addApplication( "md5deep",        archGrid2, 6, checksum_tab, PAGE_CHECKSUM );
+  addApplication( "sha1deep",       archGrid2, 7, checksum_tab, PAGE_CHECKSUM );
+  addApplication( "sha256deep",     archGrid2, 8, checksum_tab, PAGE_CHECKSUM );
+  addApplication( "tigerdeep",      archGrid2, 9, checksum_tab, PAGE_CHECKSUM );
+  addApplication( "whirlpooldeep",  archGrid2, 10, checksum_tab, PAGE_CHECKSUM );
+  addApplication( "cfv",            archGrid2, 11, checksum_tab, PAGE_CHECKSUM );
 
   kgDependenciesLayout->addWidget( tabWidget, 0, 0 );
 }
 
-void KgDependencies::addApplication( QString name, QGridLayout *grid, int row, QWidget *parent, int page )
+void KgDependencies::addApplication( QString name, QGridLayout *grid, int row, QWidget *parent, int page, QString additionalList )
 {
   QString dflt = KrServices::fullPathName( name ); /* try to autodetect the full path name */
+
+  if( dflt.isEmpty() ) {
+    QStringList list = QStringList::split( ',', additionalList );
+    for( unsigned i=0; i != list.count(); i++ )
+      if( !KrServices::fullPathName( list[ i ] ).isEmpty() ) {
+        dflt = KrServices::fullPathName( list[ i ] );
+        break;
+      }
+  }
+
   addLabel( grid, row, 0, name, parent, (QString( "label:" )+name).ascii() );
 
   KonfiguratorURLRequester *fullPath = createURLRequester( "Dependencies", name, dflt, parent, false, page );
