@@ -41,12 +41,19 @@
 
 QString KgProtocols::defaultProtocols  = "krarc,iso,tar";
 QString KgProtocols::defaultIsoMimes   = "application/x-iso";
-QString KgProtocols::defaultKrarcMimes = "application/x-ace,application/x-arj,"
-                                         "application/x-bzip2,application/x-cpio,"
+QString KgProtocols::defaultKrarcMimes = "application/x-7z,application/x-7z-compressed,"
+                                         "application/x-ace,application/x-ace-compressed,"
+                                         "application/x-arj,application/x-arj-compressed,"
+                                         "application/x-bzip2,"
+                                         "application/x-cpio,application/x-deb,"
+                                         "application/x-debian-package,"
                                          "application/x-gzip,application/x-jar,"
-                                         "application/x-lha,application/x-rar,"
-                                         "application/x-rpm,application/x-zip";
+                                         "application/x-lha,application/x-lha-compressed,"
+                                         "application/x-rar,application/x-rar-compressed,"
+                                         "application/x-rpm,"
+                                         "application/x-zip,application/x-zip-compressed";
 QString KgProtocols::defaultTarMimes   = "application/x-tar,application/x-tarz,"
+                                         "application/x-compressed-tar,"
                                          "application/x-tbz,application/x-tgz";
 
 KgProtocols::KgProtocols( bool first, QWidget* parent,  const char* name ) :
@@ -54,7 +61,6 @@ KgProtocols::KgProtocols( bool first, QWidget* parent,  const char* name ) :
 {
   QGridLayout *KgProtocolsLayout = new QGridLayout( parent );
   KgProtocolsLayout->setSpacing( 6 );
-  KgProtocolsLayout->setMargin( 11 );
 
   //  -------------------------- LINK VIEW ----------------------------------
   
