@@ -41,11 +41,10 @@ KgStartup::KgStartup( bool first, QWidget* parent,  const char* name ) :
 {
   QGridLayout *kgStartupLayout = new QGridLayout( parent );
   kgStartupLayout->setSpacing( 6 );
-  kgStartupLayout->setMargin( 11 );
 
   //  --------------------------- PANELS GROUPBOX ----------------------------------
 
-  QGroupBox *panelsGrp = createFrame( i18n( "Panels" ), parent, "panelsGrp" );
+  QGroupBox *panelsGrp = createFrame( i18n( "General" ), parent, "panelsGrp" );
   QGridLayout *panelsGrid = createGridLayout( panelsGrp->layout() );
 
   QString s = "<p><img src='toolbar|kr_profile'></p>" + i18n( "Defines the panel profile used at startup. A panel profile contains:<ul><li>all the tabs paths</li><li>the current tab</li><li>the active panel</li></ul><b>&lt;Last session&gt;</b> is a special panel profile which is saved automatically when Krusader is closed.");
@@ -60,11 +59,23 @@ KgStartup::KgStartup( bool first, QWidget* parent,  const char* name ) :
   for(unsigned int i=0; i != profileList.count(); i++ )
     comboItems[ i ].text = comboItems[ i ].value = profileList [ i ];    
   comboItems[ 0 ].value = "";
-      
+
   profileCombo = createComboBox( "Startup", "Starter Profile Name", comboItems[ 0 ].value, comboItems, profileList.count(), panelsGrp, false, false );
   profileCombo->setSizePolicy(  QSizePolicy::Expanding, QSizePolicy::Fixed);
   panelsGrid->addWidget( profileCombo, 0, 1 );
-  
+
+  //------------------------------------------------
+  panelsGrid->addMultiCellWidget( createLine( panelsGrp, "lookSep3" ), 1, 1, 0, 1 );
+
+  KONFIGURATOR_CHECKBOX_PARAM settings[] =
+    { //   cfg_class  cfg_name                default             text                              restart tooltip
+     {"Look&Feel","Show splashscreen",  _ShowSplashScreen, i18n( "Show splashscreen"  ), false,  i18n( "Display a splashscreen when starting krusader.") },
+     {"Look&Feel","Single Instance Mode", _SingleInstanceMode, i18n( "Single instance mode"  ), false,  i18n( "Only one Krusader instance is allowed to run.") }
+    };
+
+  KonfiguratorCheckBoxGroup* cbs = createCheckBoxGroup( 2, 0, settings, 2 /* settings count */, panelsGrp );
+  panelsGrid->addMultiCellWidget( cbs, 2, 2, 0, 1 );
+
   kgStartupLayout->addWidget( panelsGrp, 0, 0 );
 
   //  ------------------------ USERINTERFACE GROUPBOX ------------------------------
@@ -73,17 +84,18 @@ KgStartup::KgStartup( bool first, QWidget* parent,  const char* name ) :
   QGridLayout *uiGrid = createGridLayout( uiGrp->layout() );
 
   KONFIGURATOR_CHECKBOX_PARAM uiCheckBoxes[] =
-  //   cfg_class  cfg_name                default               text                                   restart ToolTip
-    {{"Startup","UI Save Settings",      _UiSave,               i18n( "Save settings on exit" ),       false,  i18n( "Check the state of the user interface components and restore them to their condition when last shutdown." ) },
+    { //   cfg_class  cfg_name                default               text                                   restart ToolTip
+     {"Startup","UI Save Settings",      _UiSave,               i18n( "Save settings on exit" ),       false,  i18n( "Check the state of the user interface components and restore them to their condition when last shutdown." ) },
      {"Startup","Show tool bar",         _ShowToolBar,          i18n( "Show toolbar" ),                false,  i18n( "Toolbar will be visible after startup." ) },
      {"Startup","Show status bar",       _ShowStatusBar,        i18n( "Show statusbar" ),              false,  i18n( "Statusbar will be visible after startup." ) },
      {"Startup","Show FN Keys",          _ShowFNkeys,           i18n( "Show function keys" ),          false,  i18n( "Function keys will be visible after startup." ) },
      {"Startup","Show Cmd Line",         _ShowCmdline,          i18n( "Show command line" ),           false,  i18n( "Command line will be visible after startup." ) },
      {"Startup","Show Terminal Emulator",_ShowTerminalEmulator, i18n( "Show terminal emulator" ),      false,  i18n( "Terminal emulator will be visible after startup." ) },
-     {"Startup","Remember Position",     _RememberPos,          i18n( "Save last position, size and panel settings" ), false,  i18n( "At startup, the main window will resize itself to the size it was when last shutdown. It will also appear in the same location of the screen, having panels sorted and aligned as they were before.<p>If this option is disabled, you can use the menu <i>Settings -> Save Position</i> option to manually set the main window's size and position at startup." )
-}};
+     {"Startup","Remember Position",     _RememberPos,          i18n( "Save last position, size and panel settings" ), false,  i18n( "<p>At startup, the main window will resize itself to the size it was when last shutdown. It will also appear in the same location of the screen, having panels sorted and aligned as they were before.</p><p>If this option is disabled, you can use the menu <i>Window -> Save Position</i> option to manually set the main window's size and position at startup.</p>" ) },
+     {"Startup","Start To Tray",         _StartToTray,          i18n( "Start to tray" ),               false,  i18n( "Krusader starts to tray (if minimize to tray is set), without showing the main window" ) },
+    };
 
-  uiCbGroup = createCheckBoxGroup( 1, 0, uiCheckBoxes, 7, uiGrp );
+  uiCbGroup = createCheckBoxGroup( 2, 0, uiCheckBoxes, 8, uiGrp );
   connect( uiCbGroup->find( "UI Save Settings" ), SIGNAL( stateChanged( int ) ), this, SLOT( slotDisable() ) );
 
   uiGrid->addWidget( uiCbGroup, 1, 0 );
