@@ -52,16 +52,50 @@
 #include <kinputdialog.h>
 #include <qregexp.h>
 #include <qdir.h>
+#include <qclipboard.h>
+#include <kurldrag.h>
+#include <../kicons.h>
 
 // these are the values that will exist in the menu
-#define VIEW_ID             90
-#define EDIT_ID             91
-#define FIND_ID             92
-#define FIND_NEXT_ID        93
-#define FIND_PREV_ID        94
+#define VIEW_ID                     90
+#define EDIT_ID                     91
+#define FIND_ID                     92
+#define FIND_NEXT_ID                93
+#define FIND_PREV_ID                94
+#define COPY_SELECTED_TO_CLIPBOARD  95
 //////////////////////////////////////////////////////////
 
+class LocateListView : public KListView
+{
+public:
+  LocateListView( QWidget * parent, const char * name = 0 ) : KListView( parent, name )
+  {
+  }
+
+  void startDrag()
+  {
+    KURL::List urls;
+
+    QListViewItem * item = firstChild();
+    while( item )
+    {
+      if( item->isSelected() )
+         urls.push_back( vfs::fromPathOrURL( item->text( 0 ) ) );
+
+      item = item->nextSibling();
+    }
+
+    if( urls.count() == 0 )
+      return;
+
+    KURLDrag *d = new KURLDrag(urls, this);
+    d->setPixmap( FL_LOADICON( "file" ), QPoint( -7, 0 ) );
+    d->dragCopy();
+  }
+};
+
 KProcess *  LocateDlg::updateProcess = 0;
+LocateDlg * LocateDlg::LocateDialog = 0;
 
 LocateDlg::LocateDlg() : KDialogBase(0,0,false,"Locate", KDialogBase::User1 | KDialogBase::User2 | KDialogBase::User3 | KDialogBase::Close,
       KDialogBase::User3, false, i18n("Stop"), i18n("Update DB"), i18n("Locate") ), isFeedToListBox( false )
@@ -74,13 +108,15 @@ LocateDlg::LocateDlg() : KDialogBase(0,0,false,"Locate", KDialogBase::User1 | KD
   setPlainCaption( i18n( "Krusader::Locate" ) );
   
   QHBox *hbox = new QHBox( widget, "locateHBox" );
-  new QLabel( i18n( "Search for:" ), hbox, "locateLabel" );
+  QLabel *label = new QLabel( i18n( "Search for:" ), hbox, "locateLabel" );
   locateSearchFor = new KHistoryCombo( false, hbox, "locateSearchFor" );
+  label->setBuddy( locateSearchFor );
   krConfig->setGroup("Locate");
   QStringList list = krConfig->readListEntry("Search For");
   locateSearchFor->setMaxCount(25);  // remember 25 items
   locateSearchFor->setHistoryItems(list);
   locateSearchFor->setEditable( true );
+  locateSearchFor->setDuplicatesEnabled( false );
   locateSearchFor->setSizePolicy(QSizePolicy::Expanding,QSizePolicy::Fixed);
   locateSearchFor->lineEdit()->setFocus();
 
@@ -101,7 +137,7 @@ LocateDlg::LocateDlg() : KDialogBase(0,0,false,"Locate", KDialogBase::User1 | KD
   line1->setFrameStyle( QFrame::HLine | QFrame::Sunken );
   grid->addWidget( line1, 2, 0 );
 
-  resultList=new KListView( widget );  // create the main container
+  resultList=new LocateListView( widget );  // create the main container
 
   krConfig->setGroup("Look&Feel");
   resultList->setFont(krConfig->readFontEntry("Filelist Font",_FilelistFont));
@@ -111,6 +147,7 @@ LocateDlg::LocateDlg() : KDialogBase(0,0,false,"Locate", KDialogBase::User1 | KD
   resultList->setHScrollBarMode(QScrollView::Auto);
   resultList->setShowSortIndicator(false);
   resultList->setSorting(-1);
+  resultList->setSelectionMode( QListView::Extended );
 
   resultList->addColumn( i18n("Results"), QFontMetrics(resultList->font()).width("W") * 60 );
   resultList->setColumnWidthMode(0,QListView::Maximum);
@@ -144,7 +181,7 @@ LocateDlg::LocateDlg() : KDialogBase(0,0,false,"Locate", KDialogBase::User1 | KD
   setMainWidget(widget);
   show();
 
-  exec();
+  LocateDialog = this;
 }
 
 void LocateDlg::slotUser1()   /* The stop / feed to listbox button */
@@ -203,7 +240,8 @@ void LocateDlg::slotUser3()   /* The locate button */
   enableButton( KDialogBase::User1, true );   /* enable the stop button */
   setButtonText( KDialogBase::User1, i18n( "Stop" ) ); /* the button behaves as stop */
   isFeedToListBox = false;
-  
+  resultList->setFocus();
+
   qApp->processEvents();
 
   stopping = false;
@@ -237,6 +275,7 @@ void LocateDlg::slotUser3()   /* The locate button */
   
   if( resultList->childCount() == 0 )
   {
+    locateSearchFor->setFocus();
     enableButton( KDialogBase::User1, false ); /* disable the stop button */
     isFeedToListBox = false;
   }else{
@@ -285,6 +324,8 @@ void LocateDlg::processStdout(KProcess *proc, char *buffer, int length)
         lastItem = new KListViewItem( resultList, lastItem, *it );
       else
         lastItem = new KListViewItem( resultList, *it );
+
+      lastItem->setDragEnabled( true );
     }
   }
 
@@ -322,6 +363,11 @@ void LocateDlg::slotRightClick(QListViewItem *item)
   popup.insertItem(i18n("Find next (Ctrl+N)"), FIND_NEXT_ID);
   popup.insertItem(i18n("Find previous (Ctrl+P)"), FIND_PREV_ID);
 
+  popup.insertSeparator();
+
+  popup.insertItem(i18n("Copy selected to clipboard"), COPY_SELECTED_TO_CLIPBOARD);
+
+
   int result=popup.exec(QCursor::pos());
 
   // check out the user's option
@@ -332,6 +378,7 @@ void LocateDlg::slotRightClick(QListViewItem *item)
   case FIND_ID:
   case FIND_NEXT_ID:
   case FIND_PREV_ID:
+  case COPY_SELECTED_TO_CLIPBOARD:
     operate( item, result );
     break;
   }
@@ -343,17 +390,36 @@ void LocateDlg::slotDoubleClick(QListViewItem *item)
     return;
 
   QString dirName = item->text(0);
+  QString fileName;
+
   if( !QDir( dirName ).exists() )
+  {
+    fileName = dirName.mid( dirName.findRev( '/' ) + 1 );
     dirName.truncate( dirName.findRev( '/' ) );
+  }
     
-  ACTIVE_FUNC->openUrl(vfs::fromPathOrURL( dirName ) );
+  ACTIVE_FUNC->openUrl(vfs::fromPathOrURL( dirName ), fileName );
   KDialogBase::accept();
 }
 
 void LocateDlg::keyPressEvent( QKeyEvent *e )
 {
+  if( Krusader::actCopy->shortcut().contains( KKey( e ) ) )
+  {
+    operate( 0, COPY_SELECTED_TO_CLIPBOARD );
+    e->accept();
+    return;
+  }
+
   switch ( e->key() )
   {
+  case Key_M :
+    if( e->state() == ControlButton )
+    {
+      resultList->setFocus();
+      e->accept();
+    }
+    break;
   case Key_F3 :
     if( resultList->currentItem() )
       operate( resultList->currentItem(), VIEW_ID );
@@ -381,15 +447,17 @@ void LocateDlg::keyPressEvent( QKeyEvent *e )
 
 void LocateDlg::operate( QListViewItem *item, int task )
 {
-  KURL name = vfs::fromPathOrURL( item->text( 0 ) );
+  KURL name;
+  if( item != 0 )
+    name = vfs::fromPathOrURL( item->text( 0 ) );
   
   switch ( task )
   {
   case VIEW_ID:
-    KrViewer::view( name ); // view the file
+    KrViewer::view( name, this ); // view the file
     break;
   case EDIT_ID:
-    KrViewer::edit( name ); // view the file
+    KrViewer::edit( name, this ); // view the file
     break;
   case FIND_ID:
     {
@@ -441,6 +509,27 @@ void LocateDlg::operate( QListViewItem *item, int task )
         findOptions ^= KFindDialog::FindBackwards;
     }
     break;
+  case COPY_SELECTED_TO_CLIPBOARD:
+    {
+      KURL::List urls;
+
+      QListViewItem * item = resultList->firstChild();
+      while( item )
+      {
+        if( item->isSelected() )
+           urls.push_back( vfs::fromPathOrURL( item->text( 0 ) ) );
+
+        item = item->nextSibling();
+      }
+
+      if( urls.count() == 0 )
+        return;
+
+      KURLDrag *d = new KURLDrag(urls, this);
+      d->setPixmap( FL_LOADICON( "file" ), QPoint( -7, 0 ) );
+      QApplication::clipboard()->setData( d );
+    }
+    break;
   }
 }
 
@@ -515,4 +604,10 @@ void LocateDlg::feedToListBox()
   accept();
 }
 
+void LocateDlg::reset()
+{
+  locateSearchFor->lineEdit()->setFocus();
+  locateSearchFor->lineEdit()->selectAll();
+}
+
 #include "locate.moc"
