@@ -44,11 +44,15 @@ class LocateDlg : public KDialogBase
 public:
   LocateDlg();
 
+  static LocateDlg *LocateDialog;
+
   virtual void      slotUser1();
   virtual void      slotUser2();
   virtual void      slotUser3();
   virtual void      feedToListBox();
 
+  void              reset();
+
 public slots:
   void              processStdout(KProcess *, char *, int);
   void              processStderr(KProcess *proc, char *buffer, int length);
