@@ -37,6 +37,7 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "../krusaderview.h"
 #include "../krslots.h"
 #include "../VFS/krpermhandler.h"
+#include "../VFS/krarchandler.h"
 #include "../GUI/kcmdline.h"
 #include "../Dialogs/krspecialwidgets.h"
 #include "../panelmanager.h"
@@ -87,9 +88,13 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 QString KrDetailedView::ColumnName[ KrDetailedViewProperties::MAX_COLUMNS ];
 
 KrDetailedView::KrDetailedView( QWidget *parent, bool &left, KConfig *cfg, const char *name ) :
-      KListView( parent, name ), KrView( cfg ), _currDragItem( 0L ), currentlyRenamedItem( 0 ) {
+      KListView( parent, name ), KrView( cfg ), _currDragItem( 0L ), currentlyRenamedItem( 0 ),
+      pressedItem( 0 ) {
 	setWidget( this );
 	_nameInKConfig=QString( "KrDetailedView" ) + QString( ( left ? "Left" : "Right" ) ) ;
+	krConfig->setGroup("Private");
+	if (krConfig->readBoolEntry("Enable Input Method", true))
+		setInputMethodEnabled(true);
 }
 
 void KrDetailedView::setup() {
@@ -111,7 +116,8 @@ void KrDetailedView::setup() {
       KConfigGroupSaver grpSvr( _config, "Look&Feel" );
       setFont( _config->readFontEntry( "Filelist Font", _FilelistFont ) );
       // decide on single click/double click selection
-      if ( _config->readBoolEntry( "Single Click Selects", _SingleClickSelects ) ) {
+      if ( _config->readBoolEntry( "Single Click Selects", _SingleClickSelects ) &&
+           KGlobalSettings::singleClick() ) {
          connect( this, SIGNAL( executed( QListViewItem* ) ), this, SLOT( slotExecuted( QListViewItem* ) ) );
       } else {
          connect( this, SIGNAL( clicked( QListViewItem* ) ), this, SLOT( slotClicked( QListViewItem* ) ) );
@@ -125,6 +131,7 @@ void KrDetailedView::setup() {
 		connect( this, SIGNAL( rightButtonPressed(QListViewItem*, const QPoint&, int)),
 			this, SLOT(slotRightButtonPressed(QListViewItem*, const QPoint&, int)));
       connect( this, SIGNAL( currentChanged( QListViewItem* ) ), this, SLOT( setNameToMakeCurrent( QListViewItem* ) ) );
+      connect( this, SIGNAL( currentChanged( QListViewItem* ) ), this, SLOT( transformCurrentChanged( QListViewItem* ) ) );
       connect( this, SIGNAL( mouseButtonClicked ( int, QListViewItem *, const QPoint &, int ) ),
                this, SLOT( slotMouseClicked ( int, QListViewItem *, const QPoint &, int ) ) );
       connect( &KrColorCache::getColorCache(), SIGNAL( colorsRefreshed() ), this, SLOT( refreshColors() ) );
@@ -292,6 +299,9 @@ void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
       new KrDetailedViewItem( this, ( QListViewItem* ) 0L, ( vfile* ) 0L );
    }
 
+   // text for updating the status bar
+   QString statusText = QString("%1/  ").arg( v->vfs_getOrigin().fileName() ) + i18n("Directory");
+
    int cnt = 0;
    int cl = columnSorted();
    bool as = ascendingSort();
@@ -332,7 +342,10 @@ void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
       ++_count;
       // if the item should be current - make it so
       if ( dvitem->name() == nameToMakeCurrent() )
+      {
          currentItem = static_cast<QListViewItem*>(dvitem);
+         statusText = dvitem->description();
+      }
 
       cnt++;
    }
@@ -346,6 +359,8 @@ void KrDetailedView::addItems( vfs *v, bool addUpDir ) {
       currentItem = firstChild();
    KListView::setCurrentItem( currentItem );
    ensureItemVisible( currentItem );
+
+   op()->emitItemDescription( statusText );
 }
 
 QString KrDetailedView::getCurrentItem() const {
@@ -480,17 +495,27 @@ void KrDetailedView::slotItemDescription( QListViewItem * item ) {
 void KrDetailedView::handleQuickSearchEvent( QKeyEvent * e ) {
    switch ( e->key() ) {
          case Key_Insert:
-         KListView::keyPressEvent( new QKeyEvent( QKeyEvent::KeyPress, Key_Space, 0, 0 ) );
-         keyPressEvent( new QKeyEvent( QKeyEvent::KeyPress, Key_Down, 0, 0 ) );
-         break;
+         {
+            QKeyEvent ev = QKeyEvent( QKeyEvent::KeyPress, Key_Space, 0, 0 );
+            KListView::keyPressEvent( & ev );
+            ev = QKeyEvent( QKeyEvent::KeyPress, Key_Down, 0, 0 );
+            keyPressEvent( & ev );
+            break;
+         }
          case Key_Home:
-         QListView::setCurrentItem( firstChild() );
-         keyPressEvent( new QKeyEvent( QKeyEvent::KeyPress, Key_Down, 0, 0 ) );
-         break;
+         {
+            QListView::setCurrentItem( firstChild() );
+            QKeyEvent ev = QKeyEvent( QKeyEvent::KeyPress, Key_Down, 0, 0 );
+            keyPressEvent( & ev );
+            break;
+         }
          case Key_End:
-         QListView::setCurrentItem( firstChild() );
-         keyPressEvent( new QKeyEvent( QKeyEvent::KeyPress, Key_Up, 0, 0 ) );
-         break;
+         {
+            QListView::setCurrentItem( firstChild() );
+            QKeyEvent ev = QKeyEvent( QKeyEvent::KeyPress, Key_Up, 0, 0 );
+            keyPressEvent( & ev );
+            break;
+         }
    }
 }
 
@@ -504,6 +529,8 @@ void KrDetailedView::slotCurrentChanged( QListViewItem * item ) {
 
 void KrDetailedView::contentsMousePressEvent( QMouseEvent * e ) {
    bool callDefaultHandler = true, processEvent = true, selectionChanged = false;
+   pressedItem = 0;
+
    QListViewItem * oldCurrent = currentItem();
    QListViewItem *newCurrent = itemAt( contentsToViewport( e->pos() ) );
    if (e->button() == RightButton)
@@ -529,6 +556,33 @@ void KrDetailedView::contentsMousePressEvent( QMouseEvent * e ) {
          processEvent = false;
          e->accept();
        }
+
+       if( !KrSelectionMode::getSelectionHandler()->rightButtonPreservesSelection() && KrSelectionMode::getSelectionHandler()->showContextMenu() >= 0)
+       {
+         if( (e->state() & ControlButton) && !(e->state() & AltButton) )
+         {
+            if( newCurrent )
+            {
+               newCurrent->setSelected(!newCurrent->isSelected());
+               newCurrent->repaint();
+               selectionChanged = true;
+               callDefaultHandler = false;
+               e->accept();
+            }
+         }
+         else if( !(e->state() & ControlButton) && !(e->state() & AltButton) )
+         {
+            clearSelection();
+            if( newCurrent )
+            {
+               newCurrent->setSelected( true );
+               newCurrent->repaint();
+            }
+            selectionChanged = true;
+            callDefaultHandler = false;
+            e->accept();
+         }
+       }
      }
      else
      {
@@ -630,6 +684,18 @@ void KrDetailedView::contentsMousePressEvent( QMouseEvent * e ) {
 
      if( name.isEmpty() || _dict.find( name ) == 0 ) // is the file still valid?
        newCurrent = 0;                // if not, don't do any crash...
+   } else {
+     // emitting the missing signals from QListView::contentsMousePressEvent();
+     // the right click signal is not emitted as it is used for selection
+
+     QPoint vp = contentsToViewport( e->pos() );
+
+     if( !newCurrent || ( newCurrent && newCurrent->isEnabled() ) ) {
+       emit pressed( pressedItem = newCurrent );
+       emit pressed( newCurrent, viewport()->mapToGlobal( vp ), 0 );
+     }
+
+     emit mouseButtonPressed( e->button(), newCurrent, viewport()->mapToGlobal( vp ), 0 );
    }
 
    //   if (i != 0) // comment in, if click sould NOT select
@@ -652,6 +718,25 @@ void KrDetailedView::contentsMouseReleaseEvent( QMouseEvent * e ) {
   if (e->button() == RightButton)
     contextMenuTimer.stop();
   KListView::contentsMouseReleaseEvent( e );
+
+  if( pressedItem ) {
+    QPoint vp = contentsToViewport( e->pos() );
+    QListViewItem *newCurrent = itemAt( vp );
+
+    if( pressedItem == newCurrent ) {
+      // emitting the missing signals from QListView::contentsMouseReleaseEvent();
+      // the right click signal is not emitted as it is used for selection
+
+      if( !newCurrent || ( newCurrent && newCurrent->isEnabled() ) ) {
+        emit clicked( newCurrent );
+        emit clicked( newCurrent, viewport()->mapToGlobal( vp ), 0 );
+      }
+
+      emit mouseButtonClicked( e->button(), newCurrent, viewport()->mapToGlobal( vp ), 0 );
+    }
+
+    pressedItem = 0;
+  }
 }
 
 void KrDetailedView::contentsMouseMoveEvent ( QMouseEvent * e ) {
@@ -678,7 +763,7 @@ void KrDetailedView::contentsMouseMoveEvent ( QMouseEvent * e ) {
              if (below)
                below = below->itemBelow();
            }
-           if (above == lastSwushPosition)
+           if (above && (above == lastSwushPosition))
            {
              for (; above != newItem; above = above->itemBelow())
                above->setSelected(swushSelects);
@@ -686,7 +771,7 @@ void KrDetailedView::contentsMouseMoveEvent ( QMouseEvent * e ) {
              lastSwushPosition = newItem;
              updateView();
            }
-           else if (below == lastSwushPosition)
+           else if (below && (below == lastSwushPosition))
            {
              for (; below != newItem; below = below->itemAbove())
                below->setSelected(swushSelects);
@@ -696,6 +781,11 @@ void KrDetailedView::contentsMouseMoveEvent ( QMouseEvent * e ) {
            }
            contextMenuTimer.stop();
          }
+         // emitting the missing signals from QListView::contentsMouseMoveEvent();
+         if( newItem )
+           emit onItem( newItem );
+         else
+           emit onViewport();
       }
       else
          KListView::contentsMouseMoveEvent( e );
@@ -766,6 +856,49 @@ void KrDetailedView::contentsDragMoveEvent( QDragMoveEvent * e ) {
    KListView::contentsDragMoveEvent( e );
 }
 
+void KrDetailedView::imStartEvent(QIMEvent* e)
+{
+  if ( ACTIVE_PANEL->quickSearch->isShown() ) {
+    ACTIVE_PANEL->quickSearch->myIMStartEvent( e );
+    return ;
+  }else {
+    KConfigGroupSaver grpSvr( _config, "Look&Feel" );
+    if ( !_config->readBoolEntry( "New Style Quicksearch", _NewStyleQuicksearch ) )
+      KListView::imStartEvent( e );
+    else {
+							// first, show the quicksearch if its hidden
+      if ( ACTIVE_PANEL->quickSearch->isHidden() ) {
+        ACTIVE_PANEL->quickSearch->show();
+								// hack: if the pressed key requires a scroll down, the selected
+								// item is "below" the quick search window, as the list view will
+								// realize its new size after the key processing. The following line
+								// will resize the list view immediately.
+        ACTIVE_PANEL->layout->activate();
+								// second, we need to disable the dirup action - hack!
+        krDirUp->setEnabled( false );
+      }
+							// now, send the key to the quicksearch
+      ACTIVE_PANEL->quickSearch->myIMStartEvent( e );
+    }
+  }
+}
+
+void KrDetailedView::imEndEvent(QIMEvent* e)
+{
+  if ( ACTIVE_PANEL->quickSearch->isShown() ) {
+    ACTIVE_PANEL->quickSearch->myIMEndEvent( e );
+    return ;
+  }
+}
+
+void KrDetailedView::imComposeEvent(QIMEvent* e)
+{
+  if ( ACTIVE_PANEL->quickSearch->isShown() ) {
+    ACTIVE_PANEL->quickSearch->myIMComposeEvent( e );
+    return ;
+  }
+}
+
 // TODO: for brief mode, move as much of this as possible to the viewOperator
 void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
    if ( !e || !firstChild() )
@@ -776,7 +909,10 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
    }
    switch ( e->key() ) {
          case Key_Up :
-			if (!KrSelectionMode::getSelectionHandler()->useQTSelection()) {
+         if ( e->state() == ControlButton ) { // let the panel handle it - jump to the Location Bar
+            e->ignore();
+            break;
+         } else if (!KrSelectionMode::getSelectionHandler()->useQTSelection()) {
             QListViewItem * i = currentItem();
             if ( !i ) break;
             if ( e->state() == ShiftButton ) setSelected( i, !i->isSelected() );
@@ -788,7 +924,7 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
          } else KListView::keyPressEvent(e);
          break;
          case Key_Down :
-         if ( e->state() == ControlButton ) { // let the panel handle it - jump to command line
+         if ( e->state() == ControlButton || e->state() == ( ControlButton | ShiftButton ) ) { // let the panel handle it - jump to command line
             e->ignore();
             break;
          } else if (!KrSelectionMode::getSelectionHandler()->useQTSelection()){
@@ -885,6 +1021,20 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
             if ( i->VF->vfile_isDir() ) {             // we create a return-pressed event,
                QString tmp = i->name();
                op()->emitExecuted(tmp); // thereby emulating a chdir
+            } else if( i->VF->vfile_getUrl().isLocalFile() ) {
+               bool encrypted; 
+               KURL url = i->VF->vfile_getUrl();
+               QString mime = ((vfile *)(i->VF))->vfile_getMime();
+               QString type = KRarcHandler::getType( encrypted, url.path(), mime, false );
+
+               if( KRarcHandler::arcSupported( type ) ) {
+                 KURL url = i->VF->vfile_getUrl();
+                 if( type == "-tar" || type == "-tgz" || type == "-tbz" )
+                   url.setProtocol( "tar" );
+                 else
+                   url.setProtocol( "krarc" );
+                 ACTIVE_FUNC->openUrl( url );
+               }
             }
             return ; // safety
          }
@@ -917,14 +1067,20 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
             if (KrSelectionMode::getSelectionHandler()->insertMovesDown())
                KListView::keyPressEvent( e );
             else
-               KListView::keyPressEvent( new QKeyEvent( QKeyEvent::KeyPress, Key_Space, 0, 0 ) );
+            {
+               QKeyEvent ev = QKeyEvent( QKeyEvent::KeyPress, Key_Space, 0, 0 );
+               KListView::keyPressEvent( & ev );
+            }
             break ; 
          }
          case Key_Space : {
             KrDetailedViewItem * viewItem = static_cast<KrDetailedViewItem *> ( getCurrentKrViewItem() );
             if ( !viewItem || viewItem->name() == ".." ) { // wrong type, just mark(unmark it)
                if (KrSelectionMode::getSelectionHandler()->spaceMovesDown())
-                  KListView::keyPressEvent( new QKeyEvent( QKeyEvent::KeyPress, Key_Insert, 0, 0 ) );
+               {
+                  QKeyEvent ev = QKeyEvent( QKeyEvent::KeyPress, Key_Insert, 0, 0 );
+                  KListView::keyPressEvent( & ev );
+               }
                else
                   KListView::keyPressEvent( e );
                break ; 
@@ -950,7 +1106,10 @@ void KrDetailedView::keyPressEvent( QKeyEvent * e ) {
                }
             }
 mark:       if (KrSelectionMode::getSelectionHandler()->spaceMovesDown())
-               KListView::keyPressEvent( new QKeyEvent( QKeyEvent::KeyPress, Key_Insert, 0, 0 ) );
+            {
+               QKeyEvent ev = QKeyEvent( QKeyEvent::KeyPress, Key_Insert, 0, 0 );
+               KListView::keyPressEvent( & ev );
+            }
             else
                KListView::keyPressEvent( e );
          }
@@ -1052,6 +1211,12 @@ void KrDetailedView::renameCurrentItem() {
 
    if ( c >= 0 ) {
       rename( static_cast<QListViewItem*>( it ), c );
+      // if applicable, select only the name without extension
+      KConfigGroupSaver svr(krConfig,"Look&Feel");
+      if (!krConfig->readBoolEntry("Rename Selects Extension", true)) {
+	if (it->hasExtension() && !it->VF->vfile_isDir() ) 
+		renameLineEdit()->setSelection(0, it->name().findRev(it->extension())-1);
+      }
       // signal will be emited when renaming is done, and finalization
       // will occur in inplaceRenameFinished()
    } else {
@@ -1085,13 +1250,11 @@ void KrDetailedView::inplaceRenameFinished( QListViewItem * it, int ) {
    if ( COLUMN( Extention ) != -1 && restoreView ) { // nothing happened, restore the view (if needed)
 #endif
       
-      int i;
       QString ext, name = static_cast<KrDetailedViewItem*>( it ) ->name();
-      if ( !static_cast<KrDetailedViewItem*>( it ) ->VF->vfile_isDir() && COLUMN( Extention ) != -1 )
-         if ( ( i = name.findRev( '.' ) ) > 0 ) {
-            ext = name.mid( i + 1 );
-            name = name.mid( 0, i );
-         }
+      if ( !static_cast<KrDetailedViewItem*>( it ) ->VF->vfile_isDir() && COLUMN( Extention ) != -1 ) {
+		ext = static_cast<KrDetailedViewItem*>( it ) ->extension();
+		name = static_cast<KrDetailedViewItem*>( it ) ->name( false );
+      }
       it->setText( COLUMN( Name ), name );
       it->setText( COLUMN( Extention ), ext );
       repaintItem( it );
@@ -1148,25 +1311,31 @@ void KrDetailedView::setNameToMakeCurrent( QListViewItem * it ) {
 }
 
 void KrDetailedView::slotMouseClicked( int button, QListViewItem * item, const QPoint&, int ) {
+   pressedItem = 0; // if the signals are emitted, don't emit twice at contentsMouseReleaseEvent
    if ( button == Qt::MidButton )
-      emit middleButtonClicked( item );
+      emit middleButtonClicked( dynamic_cast<KrViewItem *>( item ) );
 }
 
 void KrDetailedView::refreshColors() {
-   if ( !KrColorCache::getColorCache().isKDEDefault() ) {
-      // KDE deafult is not choosen: set the background color (as this paints the empty areas) and the alternate color
+   krConfig->setGroup("Colors");
+   bool kdeDefault = krConfig->readBoolEntry("KDE Default"); 
+   bool alternateBackgroundEnabled = krConfig->readBoolEntry("Enable Alternate Background"); 
+   if ( !kdeDefault ) {
+      // KDE default is not choosen: set the background color (as this paints the empty areas) and the alternate color
       bool isActive = hasFocus();
       if ( MAIN_VIEW && ACTIVE_PANEL && ACTIVE_PANEL->view )
          isActive = ( static_cast<KrView *>( this ) == ACTIVE_PANEL->view );
-      QColor color = KrColorCache::getColorCache().getBackgroundColor( isActive );
-      setPaletteBackgroundColor( color );
-      color = KrColorCache::getColorCache().getAlternateBackgroundColor( isActive );
-      setAlternateBackground( color );
+      QColorGroup cg;
+      KrColorCache::getColorCache().getColors(cg, KrColorItemType(KrColorItemType::File, false, isActive, false, false));
+      setPaletteBackgroundColor( cg.background() );
+
+      KrColorCache::getColorCache().getColors(cg, KrColorItemType(KrColorItemType::File, true, isActive, false, false));
+      setAlternateBackground( cg.background() );
    } else {
-      // KDE deaful tis choosen: set back the background color
+      // KDE default is choosen: set back the background color
       setPaletteBackgroundColor( KGlobalSettings::baseColor() );
       // Set the alternate color to its default or to an invalid color, to turn alternate the background off.
-      setAlternateBackground( KrColorCache::getColorCache().isAlternateBackgroundEnabled() ? KGlobalSettings::alternateBackgroundColor() : QColor() );
+      setAlternateBackground( alternateBackgroundEnabled ? KGlobalSettings::alternateBackgroundColor() : QColor() );
    }
 }
 
@@ -1231,14 +1400,35 @@ void KrDetailedView::initProperties() {
 	for (int i=0; i<KrDetailedViewProperties::MAX_COLUMNS;++i)
 		PROPS->column[i]=-1;	
 	PROPS->displayIcons = _config->readBoolEntry( "With Icons", _WithIcons );
+	bool dirsByNameAlways = _config->readBoolEntry("Always sort dirs by name", false);
 	PROPS->sortMode = static_cast<KrViewProperties::SortSpec>( KrViewProperties::Name |
-		KrViewProperties::Descending | KrViewProperties::DirsFirst );
+			KrViewProperties::Descending | KrViewProperties::DirsFirst | 
+			(dirsByNameAlways ? KrViewProperties::AlwaysSortDirsByName : 0) );
 	PROPS->numericPermissions = _config->readBoolEntry("Numeric permissions", _NumericPermissions);
 	if ( !_config->readBoolEntry( "Case Sensative Sort", _CaseSensativeSort ) )
       	PROPS->sortMode = static_cast<KrViewProperties::SortSpec>( _properties->sortMode |
 				 KrViewProperties::IgnoreCase );
 	PROPS->humanReadableSize = krConfig->readBoolEntry("Human Readable Size", _HumanReadableSize);
 	PROPS->localeAwareCompareIsCaseSensitive = QString( "a" ).localeAwareCompare( "B" ) > 0; // see KDE bug #40131
+	QStringList defaultAtomicExtensions;
+	defaultAtomicExtensions += ".tar.gz";
+	defaultAtomicExtensions += ".tar.bz2";
+	defaultAtomicExtensions += ".moc.cpp";
+	QStringList atomicExtensions = krConfig->readListEntry("Atomic Extensions", defaultAtomicExtensions);
+	for (QStringList::iterator i = atomicExtensions.begin(); i != atomicExtensions.end(); )
+	{
+		QString & ext = *i;
+		ext = ext.stripWhiteSpace();
+		if (!ext.length())
+		{
+			i = atomicExtensions.remove(i);
+			continue;
+		}
+		if (!ext.startsWith("."))
+			ext.insert(0, '.');
+		++i;
+	}
+	PROPS->atomicExtensions = atomicExtensions;
 }
 
 void KrDetailedView::selectColumns()
@@ -1348,7 +1538,7 @@ void KrDetailedView::slotRightButtonPressed(QListViewItem*, const QPoint& point,
 // hack: this needs to be done in a more cross-view way
 void KrDetailedView::slotSortOrderChanged(int col) {
 	// map the column to a sort specification
-	KrViewProperties::SortSpec sp;
+	KrViewProperties::SortSpec sp = KrViewProperties::Name;
 	int i;
 	for (i = 0; i < KrDetailedViewProperties::MAX_COLUMNS; ++i) {
 		if (PROPS->column[i] == col) break;
@@ -1380,6 +1570,8 @@ void KrDetailedView::slotSortOrderChanged(int col) {
 		sp = static_cast<KrViewProperties::SortSpec>(sp | KrViewProperties::IgnoreCase);
 	if (sortMode() & KrViewProperties::Descending)
 		sp = static_cast<KrViewProperties::SortSpec>(sp | KrViewProperties::Descending);
+	if (sortMode() & KrViewProperties::AlwaysSortDirsByName)
+		sp = static_cast<KrViewProperties::SortSpec>(sp | KrViewProperties::AlwaysSortDirsByName);
 	// fix the ascending/decending stuff
 	if (sortMode() == sp) {
 		if (sp & KrViewProperties::Descending) 
@@ -1387,6 +1579,9 @@ void KrDetailedView::slotSortOrderChanged(int col) {
 		else sp = static_cast<KrViewProperties::SortSpec>(sp | KrViewProperties::Descending);
 	}
 	PROPS->sortMode = sp;
+	
+	if( !_focused )
+		op()->emitNeedFocus();
 }
 
 #include "krdetailedview.moc"
