@@ -99,7 +99,8 @@ public:
    virtual inline void restoreSettings() { KListView::restoreLayout( _config, nameInKConfig() ); }
 
 signals:
-   void middleButtonClicked( QListViewItem *item );
+   void middleButtonClicked( KrViewItem *item );
+   void currentChanged( KrViewItem *item );
 
 protected:
 	virtual void setup();
@@ -112,6 +113,9 @@ protected:
    void selectColumns();
    
    virtual void keyPressEvent( QKeyEvent *e );
+   virtual void imStartEvent( QIMEvent* e );
+   virtual void imEndEvent( QIMEvent *e );
+   virtual void imComposeEvent( QIMEvent *e );
    virtual void contentsMousePressEvent( QMouseEvent *e );
    virtual void contentsMouseReleaseEvent (QMouseEvent *e);
    virtual void contentsMouseMoveEvent ( QMouseEvent * e );
@@ -138,7 +142,8 @@ protected slots:
 	void sortOrderChanged(int);
 	void slotRightButtonPressed(QListViewItem*, const QPoint& point, int);
 	void slotSortOrderChanged(int col);
-	
+   void transformCurrentChanged( QListViewItem * item ) { emit currentChanged( dynamic_cast<KrViewItem *>(item ) ); }
+
    /**
     * used internally to produce the signal middleButtonClicked()
     */
@@ -169,6 +174,7 @@ private:
    QTimer contextMenuTimer;
    QPoint contextMenuPoint;
    QListViewItem *currentlyRenamedItem;
+   QListViewItem *pressedItem;
 };
 
 #endif /* KRDETAILEDVIEW_H */
