@@ -8,6 +8,41 @@
 
 #define PROPS	static_cast<const KrViewProperties*>(_viewProperties)
 
+QString atomicExtensions[] = { 
+	".tar.gz", 
+	".tar.bz2", 
+	".moc.cpp"
+};
+
+KrViewItem::KrViewItem(vfile *vf, const KrViewProperties* properties): 
+	_vf(vf), dummyVfile(false), _viewProperties(properties), _hasExtension(false), _hidden(false), _extension("") {
+	if (vf) {
+		// check if the file has an extension
+		const QString& vfName = vf->vfile_getName();
+		int loc = vfName.findRev('.');
+		if (loc>0) { // avoid mishandling of .bashrc and friend
+			// check if it has one of the predefined 'atomic extensions'
+			for (QStringList::const_iterator i = PROPS->atomicExtensions.begin(); i != PROPS->atomicExtensions.end(); ++i) {
+				if (vfName.endsWith(*i)){
+					loc = vfName.length() - (*i).length();
+					break;
+				}
+			}
+			_name = vfName.left(loc);
+			_extension = vfName.mid(loc+1);
+			_hasExtension=true;
+		}
+		
+		if( vfName.startsWith(".") )
+			_hidden = true;
+	}
+}
+
+const QString& KrViewItem::name(bool withExtension) const {
+	if (!withExtension && _hasExtension) return _name;
+	else return _vf->vfile_getName();
+}
+
 QString KrViewItem::description() const {
 	if (dummyVfile) return i18n("Climb up the directory tree");
 	// else is implied
