@@ -28,8 +28,6 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 *                                                                         *
 ***************************************************************************/
 
-//#define TESTING_BRIEF_VIEW
-
 #include <unistd.h>
 #include <sys/param.h>
 // QT includes
@@ -83,13 +81,13 @@ YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD
 #include "../Dialogs/krspwidgets.h"
 #include "../Dialogs/krspecialwidgets.h"
 #include "../GUI/kcmdline.h"
+#include "../Dialogs/percentalsplitter.h"
 #include "krdetailedview.h"
-#ifdef TESTING_BRIEF_VIEW
 #include "krbriefview.h"
-#endif
 #include "krpreviewpopup.h"
 #include "../GUI/dirhistorybutton.h"
 #include "../GUI/dirhistoryqueue.h"
+#include "../GUI/mediabutton.h"
 #include "../GUI/syncbrowsebutton.h"
 #include "../krservices.h"
 #include "panelpopup.h" 
@@ -109,14 +107,18 @@ typedef QValueList<KServiceOffer> OfferList;
 /////////////////////////////////////////////////////
 // 					The list panel constructor       //
 /////////////////////////////////////////////////////
-ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
-      QWidget( parent, name ), colorMask( 255 ), compareMode( false ), currDragItem( 0 ), statsAgent( 0 ), 
+ListPanel::ListPanel( QString typeIn, QWidget *parent, bool &left, const char *name ) :
+      QWidget( parent, name ), panelType( typeIn ), colorMask( 255 ), compareMode( false ), currDragItem( 0 ), statsAgent( 0 ), 
 		quickSearch( 0 ), cdRootButton( 0 ), cdUpButton( 0 ), popupBtn(0), popup(0),inlineRefreshJob(0), _left( left ) {
 
    func = new ListPanelFunc( this );
    setAcceptDrops( true );
    layout = new QGridLayout( this, 3, 3 );
 
+   mediaButton = new MediaButton( this, "mediaButton" );
+   connect( mediaButton, SIGNAL( pressed() ), this, SLOT( slotFocusOnMe() ) );
+   connect( mediaButton, SIGNAL( openUrl( const KURL& ) ), func, SLOT( openUrl( const KURL& ) ) );
+
    status = new KrSqueezedTextLabel( this );
    krConfig->setGroup( "Look&Feel" );
    status->setFont( krConfig->readFontEntry( "Filelist Font", _FilelistFont ) );
@@ -148,7 +150,7 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
                                "current location to the list, edit bookmarks "
                                "or add subfolder to the list." ) );
 										 
-   QHBoxLayout *totalsLayout = new QHBoxLayout(this);
+   QHBoxLayout *totalsLayout = new QHBoxLayout;
 	totals = new KrSqueezedTextLabel( this );
    krConfig->setGroup( "Look&Feel" );
    totals->setFont( krConfig->readFontEntry( "Filelist Font", _FilelistFont ) );
@@ -204,13 +206,16 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
       ( origin, i18n( "Use superb KDE file dialog to choose location. " ) );
    origin->setShowLocalProtocol( false );
    origin->lineEdit() ->setURLDropsEnabled( true );
+   origin->lineEdit() ->installEventFilter( this );
    QWhatsThis::add
       ( origin->lineEdit(), i18n( "Name of directory where you are. You can also "
                                   "enter name of desired location to move there. "
                                   "Use of Net protocols like ftp or fish is possible." ) );
    origin->setMode( KFile::Directory | KFile::ExistingOnly );
    connect( origin, SIGNAL( returnPressed( const QString& ) ), func, SLOT( openUrl( const QString& ) ) );
+   connect( origin, SIGNAL( returnPressed( const QString& ) ), this, SLOT( slotFocusOnMe() ) );
    connect( origin, SIGNAL( urlSelected( const QString& ) ), func, SLOT( openUrl( const QString& ) ) );
+   connect( origin, SIGNAL( urlSelected( const QString& ) ), this, SLOT( slotFocusOnMe() ) );
    
 	// this is here on purpose, do not move up!
 	if (clearButton) {
@@ -249,45 +254,78 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
 
    setPanelToolbar();
 
+   header = new QHeader( this );
+   header->hide();
+
 	// create a splitter to hold the view and the popup
-	QSplitter *splt = new QSplitter(this);
+	splt = new PercentalSplitter(this);
 	splt->setChildrenCollapsible(true);
 	splt->setOrientation(QObject::Vertical);
 
-#ifdef TESTING_BRIEF_VIEW // code is used for testing purposes only! do not enable it!!! 
-	view = new KrBriefView( splt, _left, krConfig );
-   view->init();
-/* TODO
-   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( middleButtonClicked( QListViewItem * ) ), SLOTS, SLOT( newTab( QListViewItem * ) ) );
-	connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( currentChanged( QListViewItem* ) ), 
-		SLOTS, SLOT( updatePopupPanel( QListViewItem* ) ) );
+	createView();
+	
+   // make sure that a focus/path change reflects in the command line and activePanel
+   connect( this, SIGNAL( cmdLineUpdate( QString ) ), SLOTS, SLOT( slotCurrentChanged( QString ) ) );
+   connect( this, SIGNAL( activePanelChanged( ListPanel * ) ), SLOTS, SLOT( slotSetActivePanel( ListPanel * ) ) );
+	
+	// add a popup
+	popup = new PanelPopup(splt, left);
+	connect(popup, SIGNAL(selection(const KURL&)), SLOTS, SLOT(refresh(const KURL&)));
+	connect(popup, SIGNAL(hideMe()), this, SLOT(togglePanelPopup()));
+	popup->hide();
+	
+   // finish the layout
+	layout->addMultiCellWidget( hbox, 0, 0, 0, 3 );
+   layout->addWidget( mediaButton, 1, 0 );
+   layout->addWidget( status, 1, 1 );
+   layout->addWidget( historyButton, 1, 2 );
+   layout->addWidget( bookmarksButton, 1, 3 );
+   layout->addMultiCellWidget( header, 2, 2, 0, 3 );
+   layout->addMultiCellWidget( splt, 3, 3, 0, 3 );
+   layout->addMultiCellWidget( quickSearch, 4, 4, 0, 3 );
+   quickSearch->hide();
+   layout->addMultiCellLayout( totalsLayout, 5, 5, 0, 3 );
+   //filter = ALL;
+}
 
-	// connect quicksearch
-   connect( quickSearch, SIGNAL( textChanged( const QString& ) ),
-            dynamic_cast<KrDetailedView*>( view ), SLOT( quickSearch( const QString& ) ) );
-   connect( quickSearch, SIGNAL( otherMatching( const QString&, int ) ),
-            dynamic_cast<KrDetailedView*>( view ), SLOT( quickSearch( const QString& , int ) ) );
-   connect( quickSearch, SIGNAL( stop( QKeyEvent* ) ),
-            dynamic_cast<KrDetailedView*>( view ), SLOT( stopQuickSearch( QKeyEvent* ) ) );
-   connect( quickSearch, SIGNAL( process( QKeyEvent* ) ),
-            dynamic_cast<KrDetailedView*>( view ), SLOT( handleQuickSearchEvent( QKeyEvent* ) ) );	
-*/
-#else	
-   view = new KrDetailedView( splt, _left, krConfig );
-   view->init();
-   connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( middleButtonClicked( QListViewItem * ) ), SLOTS, SLOT( newTab( QListViewItem * ) ) );
-	connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( currentChanged( QListViewItem* ) ), 
-		SLOTS, SLOT( updatePopupPanel( QListViewItem* ) ) );
-	// connect quicksearch
-   connect( quickSearch, SIGNAL( textChanged( const QString& ) ),
-            dynamic_cast<KrDetailedView*>( view ), SLOT( quickSearch( const QString& ) ) );
-   connect( quickSearch, SIGNAL( otherMatching( const QString&, int ) ),
-            dynamic_cast<KrDetailedView*>( view ), SLOT( quickSearch( const QString& , int ) ) );
-   connect( quickSearch, SIGNAL( stop( QKeyEvent* ) ),
-            dynamic_cast<KrDetailedView*>( view ), SLOT( stopQuickSearch( QKeyEvent* ) ) );
-   connect( quickSearch, SIGNAL( process( QKeyEvent* ) ),
-            dynamic_cast<KrDetailedView*>( view ), SLOT( handleQuickSearchEvent( QKeyEvent* ) ) );
-#endif
+void ListPanel::createView()
+{
+	header->hide();
+	if( panelType == "Brief" )
+	{
+		view = new KrBriefView( header, splt, _left, krConfig );
+		view->init();
+		
+		connect( dynamic_cast<KrBriefView*>( view ), SIGNAL( middleButtonClicked( KrViewItem * ) ), SLOTS, SLOT( newTab( KrViewItem * ) ) );
+		connect( dynamic_cast<KrBriefView*>( view ), SIGNAL( currentChanged( KrViewItem * ) ), 
+			SLOTS, SLOT( updatePopupPanel( KrViewItem* ) ) );
+
+		// connect quicksearch
+		connect( quickSearch, SIGNAL( textChanged( const QString& ) ),
+			dynamic_cast<KrBriefView*>( view ), SLOT( quickSearch( const QString& ) ) );
+		connect( quickSearch, SIGNAL( otherMatching( const QString&, int ) ),
+			dynamic_cast<KrBriefView*>( view ), SLOT( quickSearch( const QString& , int ) ) );
+		connect( quickSearch, SIGNAL( stop( QKeyEvent* ) ),
+			dynamic_cast<KrBriefView*>( view ), SLOT( stopQuickSearch( QKeyEvent* ) ) );
+		connect( quickSearch, SIGNAL( process( QKeyEvent* ) ),
+			dynamic_cast<KrBriefView*>( view ), SLOT( handleQuickSearchEvent( QKeyEvent* ) ) );
+	} else { /* Detailed */
+		panelType = "Detailed";
+		view = new KrDetailedView( splt, _left, krConfig );
+		view->init();
+		connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( middleButtonClicked( KrViewItem * ) ), SLOTS, SLOT( newTab( KrViewItem * ) ) );
+		connect( dynamic_cast<KrDetailedView*>( view ), SIGNAL( currentChanged( KrViewItem * ) ), 
+			SLOTS, SLOT( updatePopupPanel( KrViewItem * ) ) );
+		// connect quicksearch
+		connect( quickSearch, SIGNAL( textChanged( const QString& ) ),
+			dynamic_cast<KrDetailedView*>( view ), SLOT( quickSearch( const QString& ) ) );
+		connect( quickSearch, SIGNAL( otherMatching( const QString&, int ) ),
+			dynamic_cast<KrDetailedView*>( view ), SLOT( quickSearch( const QString& , int ) ) );
+		connect( quickSearch, SIGNAL( stop( QKeyEvent* ) ),
+			dynamic_cast<KrDetailedView*>( view ), SLOT( stopQuickSearch( QKeyEvent* ) ) );
+		connect( quickSearch, SIGNAL( process( QKeyEvent* ) ),
+			dynamic_cast<KrDetailedView*>( view ), SLOT( handleQuickSearchEvent( QKeyEvent* ) ) );
+	}
 
    connect( view->op(), SIGNAL( renameItem( const QString &, const QString & ) ),
             func, SLOT( rename( const QString &, const QString & ) ) );
@@ -300,26 +338,23 @@ ListPanel::ListPanel( QWidget *parent, bool &left, const char *name ) :
    	this, SLOT( popEmptyRightClickMenu( const QPoint & ) ) );
    connect( view->op(), SIGNAL( letsDrag( QStringList, QPixmap ) ), this, SLOT( startDragging( QStringList, QPixmap ) ) );
    connect( view->op(), SIGNAL( gotDrop( QDropEvent * ) ), this, SLOT( handleDropOnView( QDropEvent * ) ) );
-   // make sure that a focus/path change reflects in the command line and activePanel
-   connect( this, SIGNAL( cmdLineUpdate( QString ) ), SLOTS, SLOT( slotCurrentChanged( QString ) ) );
-   connect( this, SIGNAL( activePanelChanged( ListPanel * ) ), SLOTS, SLOT( slotSetActivePanel( ListPanel * ) ) );
-	
-	// add a popup
-	popup = new PanelPopup(splt, left);
-	connect(popup, SIGNAL(selection(const KURL&)), SLOTS, SLOT(refresh(const KURL&)));
-	connect(popup, SIGNAL(hideMe()), this, SLOT(togglePanelPopup()));
-	popup->hide();
-	
-   // finish the layout
-	layout->addMultiCellWidget( hbox, 0, 0, 0, 2 );
-   layout->addWidget( status, 1, 0 );
-   layout->addWidget( historyButton, 1, 1 );
-   layout->addWidget( bookmarksButton, 1, 2 );
-	layout->addMultiCellWidget( splt, 2, 2, 0, 2 );
-   layout->addMultiCellWidget( quickSearch, 3, 3, 0, 2 );
-   quickSearch->hide();
-   layout->addMultiCellLayout( totalsLayout, 4, 4, 0, 2 );
-   //filter = ALL;
+}
+
+void ListPanel::changeType( const QString & type )
+{
+   if( panelType != type )
+   {
+      panelType = type;
+      delete view;
+      createView();
+
+      slotStartUpdate();
+
+      if( panelType == "Brief" )
+         dynamic_cast<KrBriefView*>( view )->show();
+      else /* Detailed */
+         dynamic_cast<KrDetailedView*>( view )->show();
+   }
 }
 
 ListPanel::~ListPanel() {
@@ -338,6 +373,35 @@ ListPanel::~ListPanel() {
    delete layout;
 }
 
+int ListPanel::getProperties()
+{
+   int props = 0;
+   if( syncBrowseButton->state() == SYNCBROWSE_CD )
+      props |= PROP_SYNC_BUTTON_ON;
+   return props;
+}
+
+void ListPanel::setProperties( int prop )
+{
+   if( prop & PROP_SYNC_BUTTON_ON )
+       syncBrowseButton->setOn( true );
+   else
+       syncBrowseButton->setOn( false );
+}
+
+bool ListPanel::eventFilter ( QObject * watched, QEvent * e ) {
+	if( e->type() == QEvent::KeyPress && origin->lineEdit() == watched ) {
+		QKeyEvent *ke = (QKeyEvent *)e;
+		
+		if( ( ke->key() ==  Key_Down ) && ( ke->state() == ControlButton ) ) {
+			slotFocusOnMe();
+			return true;
+		}
+	}
+	return false;
+}
+
+
 void ListPanel::togglePanelPopup() {
 	if (popup->isHidden()) {
 		if (popupSizes.count() > 0) {
@@ -361,6 +425,8 @@ void ListPanel::togglePanelPopup() {
 		QValueList<int> lst;
 		lst << height() << 0;
 		dynamic_cast<QSplitter*>(popup->parent())->setSizes(lst);
+		if( ACTIVE_PANEL )
+			ACTIVE_PANEL->slotFocusOnMe();
 	}
 }
 
@@ -547,12 +613,35 @@ void ListPanel::slotFocusOnMe() {
    emit activePanelChanged( this );
 
    func->refreshActions();
-   KrDetailedView * v = dynamic_cast<KrDetailedView *>( view );
-   if ( v )
-      v->refreshColors();
-   v = dynamic_cast<KrDetailedView *>( otherPanel->view );
-   if ( v )
-      v->refreshColors();
+   
+   Krusader::actDetailedView->setEnabled( panelType != "Detailed" ); // enable/disable the detailed view action
+   Krusader::actBriefView->setEnabled( panelType != "Brief" );       // enable/disable the brief view action
+
+   if( panelType == "Brief" )
+   {
+      KrBriefView * v = dynamic_cast<KrBriefView *>( view );
+      if ( v )
+         v->refreshColors();
+   }
+   else /* detailed */
+   {
+      KrDetailedView * v = dynamic_cast<KrDetailedView *>( view );
+      if ( v )
+         v->refreshColors();
+   }
+   
+   if( otherPanel->panelType == "Brief" )
+   {
+      KrBriefView * v = dynamic_cast<KrBriefView *>( otherPanel->view );
+      if ( v )
+         v->refreshColors();
+   }
+   else /* detailed */
+   {   
+      KrDetailedView *v = dynamic_cast<KrDetailedView *>( otherPanel->view );
+      if ( v )
+         v->refreshColors();
+   }
 }
 
 // this is used to start the panel, AFTER setOther() has been used
@@ -572,6 +661,7 @@ void ListPanel::start( KURL url, bool immediate ) {
    else
      func->openUrl( virt );
 
+   slotFocusOnMe();
    setJumpBack( virt );
 }
 
@@ -591,7 +681,7 @@ void ListPanel::slotStartUpdate() {
 
    if ( func->files() ->vfs_getType() == vfs::NORMAL )
       _realPath = virtualPath();
-   this->origin->setURL( virtualPath().prettyURL() );
+   this->origin->setURL( vfs::pathOrURL( virtualPath() ) );
    emit pathChanged( this );
    emit cmdLineUpdate( realPath() );	// update the command line
 
@@ -599,7 +689,7 @@ void ListPanel::slotStartUpdate() {
    slotUpdate();
    if ( compareMode ) {
       otherPanel->view->clear();
-      ( ( ListPanel* ) otherPanel ) ->slotUpdate();
+      otherPanel->slotUpdate();
    }
    // return cursor to normal arrow
    setCursor( KCursor::arrowCursor() );
@@ -741,6 +831,13 @@ void ListPanel::handleDropOnView( QDropEvent *e, QWidget *widget ) {
       return ;
    }
 
+   bool isLocal = true;
+   for( unsigned u = 0; u != URLs.count(); u++ )
+     if( !URLs[ u ].isLocalFile() ) {
+       isLocal = false;
+       break;
+     }
+
    KIO::CopyJob::CopyMode mode = KIO::CopyJob::Copy;
 
    // the KURL::List is finished, let's go
@@ -750,7 +847,7 @@ void ListPanel::handleDropOnView( QDropEvent *e, QWidget *widget ) {
    if ( func->files() ->vfs_isWritable() )
       popup.insertItem( i18n( "Move Here" ), 2 );
    if ( func->files() ->vfs_getType() == vfs::NORMAL &&
-         otherPanel->func->files() ->vfs_getType() == vfs::NORMAL )
+         isLocal )
       popup.insertItem( i18n( "Link Here" ), 3 );
    popup.insertItem( i18n( "Cancel" ), 4 );
    QPoint tmp = widget->mapToGlobal( e->pos() );
@@ -846,7 +943,6 @@ void ListPanel::keyPressEvent( QKeyEvent *e ) {
          		if (vf && vf->vfile_isDir()) SLOTS->newTab(vf->vfile_getUrl());
          	} else {
 					SLOTS->insertFileName( ( e->state() & ShiftButton ) != 0 );
-					MAIN_VIEW->cmdLine->setFocus();
             }
          } else e->ignore();
          break;
@@ -880,14 +976,21 @@ void ListPanel::keyPressEvent( QKeyEvent *e ) {
          if ( e->state() == ControlButton ) { // give the keyboard focus to the command line
             if ( MAIN_VIEW->cmdLine->isVisible() )
                MAIN_VIEW->cmdLineFocus();
-            else if ( MAIN_VIEW->terminal_dock->isVisible() )
-              MAIN_VIEW->terminal_dock->setFocus();
+            else 
+               MAIN_VIEW->focusTerminalEmulator();
             return ;
+         } else if ( e->state() == ( ControlButton | ShiftButton ) ) { // give the keyboard focus to TE
+           MAIN_VIEW->focusTerminalEmulator();
          } else
             e->ignore();
          break;
 
 			case Key_Up :
+          if ( e->state() == ControlButton ) { // give the keyboard focus to the command line
+            origin->lineEdit()->setFocus();
+            return ;
+          } else
+             e->ignore();
 			break;
 
          default:
