@@ -57,6 +57,8 @@
 // use our version of it, until kde fixes theirs
 #include "../MountMan/kdiskfreesp.h"
 
+#define PROP_SYNC_BUTTON_ON               1
+
 class vfs;
 class vfile;
 class KRdirWatch;
@@ -66,11 +68,13 @@ class BookmarksButton;
 class KrQuickSearch;
 class DirHistoryButton;
 class DirHistoryQueue;
+class MediaButton;
 class PanelPopup;
 class SyncBrowseButton;
 class KrBookmarkButton;
 class KPushButton;
 class ListPanelFunc;
+class QHeader;
 
 class ListPanel : public QWidget {
    friend class ListPanelFunc;
@@ -79,9 +83,13 @@ public:
 	#define ITEM2VFILE(PANEL_PTR, KRVIEWITEM)		PANEL_PTR->func->files()->vfs_search(KRVIEWITEM->name())
 	#define NAME2VFILE(PANEL_PTR, STRING_NAME)	PANEL_PTR->func->files()->vfs_search(STRING_NAME)
    // constructor create the panel, but DOESN'T fill it with data, use start()
-   ListPanel( QWidget *parent, bool &left, const char *name = 0 );
+   ListPanel( QString panelType, QWidget *parent, bool &left, const char *name = 0 );
    ~ListPanel();
    void start( KURL url = KURL(), bool immediate = false );
+   
+   const QString & getType() { return panelType; }
+   void changeType( const QString & );
+   
    KURL virtualPath() const;
 	QString realPath() const;
    QString getCurrentName();
@@ -93,6 +101,9 @@ public:
    void jumpBack();
    void setJumpBack( KURL url );
 
+   int  getProperties();
+   void setProperties( int );
+
 public slots:
    void gotStats( const QString &mountPoint, unsigned long kBSize, unsigned long kBUsed, unsigned long kBAvail); // displays filesystem status
    void popRightClickMenu( const QPoint& );
@@ -131,6 +142,9 @@ protected:
    virtual void keyPressEvent( QKeyEvent *e );
    virtual void showEvent( QShowEvent * );
    virtual void hideEvent( QHideEvent * );
+   virtual bool eventFilter ( QObject * watched, QEvent * e );
+   
+   void createView();
 
 protected slots:
    void handleDropOnView(QDropEvent *, QWidget *destWidget=0); // handles drops on the view only
@@ -152,6 +166,7 @@ signals:
    void finishedDragging();              // currently
 
 public:
+   QString panelType;
    ListPanelFunc	*func;
    KrView *view;
    ListPanel	*otherPanel;
@@ -176,9 +191,12 @@ public:
    KrBookmarkButton *bookmarksButton;
    DirHistoryQueue* dirHistoryQueue;
    DirHistoryButton* historyButton;
+   MediaButton *mediaButton;
    SyncBrowseButton *syncBrowseButton;
 	KPushButton *inlineRefreshCancelButton;
 	KIO::Job *inlineRefreshJob;
+	QSplitter *splt;
+   QHeader * header;
 
 protected:
    KURL _realPath; // named with _ to keep realPath() compatability
