@@ -66,6 +66,7 @@ A
 #include "../VFS/krpermhandler.h"
 #include "../VFS/krvfshandler.h"
 #include "../VFS/preservingcopyjob.h"
+#include "../VFS/virtualcopyjob.h"
 #include "../Dialogs/packgui.h"
 #include "../Dialogs/krdialogs.h"
 #include "../Dialogs/krpleasewait.h"
@@ -75,6 +76,7 @@ A
 #include "../resources.h"
 #include "../krservices.h"
 #include "../GUI/syncbrowsebutton.h"
+#include "../Queue/queue_mgr.h"
 #include "krdrag.h"
 #include <kurldrag.h>
 
@@ -117,8 +119,6 @@ void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 		}
 	}
 
-	panel->slotFocusOnMe();
-
 	// if we are not refreshing to current URL
 	bool is_equal_url = files() ->vfs_getOrigin().equals( url, true );
 	
@@ -141,6 +141,9 @@ void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 	vfs* v = 0;
 	if ( !urlStack.top().equals( url ) )
 		urlStack.push( url );
+	// count home many urls is in the stack, so later on, we'll know if the refresh was a success
+	uint stackSize = urlStack.size();
+	bool refreshFailed = true; // assume the worst
 	while ( true ) {
 		KURL u = urlStack.pop();
 		//u.adjustPath(-1); // remove trailing "/"
@@ -156,11 +159,19 @@ void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 				vfsP->vfs_requestDelete();                                
 			}
 			vfsP = v; // v != 0 so this is safe
+		} else {
+			if( vfsP->vfs_isBusy() )
+			{
+				delayURL = url;               /* this function is useful for FTP url-s and bookmarks */
+				delayTimer.start( 100, true );  /* if vfs is busy try refreshing later */
+				return;
+			}
 		}
 		connect( files(), SIGNAL(startJob(KIO::Job* )),
 				panel, SLOT(slotJobStarted(KIO::Job* )));
-		if ( vfsP->vfs_refresh( u ) )
+		if ( vfsP->vfs_refresh( u ) ) {
 			break; // we have a valid refreshed URL now
+		}
 		if ( vfsP == 0 )  // the object was deleted during vfs_refresh? Hoping the best...
 			return;                
 		// prevent repeated error messages
@@ -170,6 +181,11 @@ void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 	}
 	vfsP->vfs_setQuiet( false );
 
+	// if we popped exactly 1 url from the stack, it means the url we were
+	// given was refreshed successfully.
+	if (stackSize == urlStack.size() + 1)
+		refreshFailed = false;
+
 	// update the urls stack
 	if ( !files() ->vfs_getOrigin().equals( urlStack.top() ) ) {
 		urlStack.push( files() ->vfs_getOrigin() );
@@ -192,6 +208,13 @@ void ListPanelFunc::immediateOpenUrl( const KURL& urlIn ) {
 	// on local file system change the working directory
 	if ( files() ->vfs_getType() == vfs::NORMAL )
 		chdir( files() ->vfs_getOrigin().path().local8Bit() );
+	
+	// see if the open url operation failed, and if so, 
+	// put the attempted url in the origin bar and let the user change it
+	if (refreshFailed) {
+		panel->origin->setURL(urlIn.prettyURL());
+		panel->origin->setFocus();
+	}
 }
 
 void ListPanelFunc::openUrl( const KURL& url, const QString& nameToMakeCurrent ) {
@@ -354,7 +377,7 @@ void ListPanelFunc::terminal() {
 	}
 
 	if ( !proc.start( KProcess::DontCare ) )
-		KMessageBox::sorry( krApp, i18n( "Can't open " ) + "\"" + term + "\"" );
+		KMessageBox::sorry( krApp, i18n( "<qt>Can't open <b>%1</b></qt>" ).arg(term) );
 
 	chdir( save.local8Bit() );
 }
@@ -386,6 +409,7 @@ void ListPanelFunc::moveFiles() {
 		return ;  // safety
 
 	KURL dest = panel->otherPanel->virtualPath();
+	KURL virtualBaseURL;
 
 	QString destProtocol = dest.protocol();
 	if ( destProtocol == "krarc" || destProtocol == "tar" || destProtocol == "zip" ) {
@@ -395,7 +419,7 @@ void ListPanelFunc::moveFiles() {
 
 	krConfig->setGroup( "Advanced" );
 	if ( krConfig->readBoolEntry( "Confirm Move", _ConfirmMove ) ) {
-		bool preserveDate = krConfig->readBoolEntry( "PreserveDate", _PreserveDate );
+		bool preserveAttrs = krConfig->readBoolEntry( "PreserveAttributes", _PreserveAttributes );
 		QString s;
 
   if( fileNames.count() == 1 )
@@ -404,10 +428,11 @@ void ListPanelFunc::moveFiles() {
     s = i18n("Move %n file to:", "Move %n files to:", fileNames.count());
 
 		// ask the user for the copy dest
-		dest = KChooseDir::getDir(s, dest, panel->virtualPath(), preserveDate);
+		virtualBaseURL = getVirtualBaseURL();
+		dest = KChooseDir::getDir(s, dest, panel->virtualPath(), preserveAttrs, virtualBaseURL);
 		if ( dest.isEmpty() ) return ; // the user canceled
-		if( preserveDate )
-			pmode = PM_PRESERVE_DATE;
+		if( preserveAttrs )
+			pmode = PM_PRESERVE_ATTR;
 		else
 			pmode = PM_NONE;
 	}
@@ -421,8 +446,15 @@ void ListPanelFunc::moveFiles() {
 	// file above the current item;
 	panel->prepareToDelete();
 
+	if( !virtualBaseURL.isEmpty() ) {
+		// keep the directory structure for virtual paths
+		VirtualCopyJob *vjob = new VirtualCopyJob( &fileNames, files(), dest, virtualBaseURL, pmode, KIO::CopyJob::Move, false, true );
+		connect( vjob, SIGNAL( result( KIO::Job* ) ), this, SLOT( refresh() ) );
+		if ( dest.equals( panel->otherPanel->virtualPath(), true ) )
+			connect( vjob, SIGNAL( result( KIO::Job* ) ), panel->otherPanel->func, SLOT( refresh() ) );
+	}
 	// if we are not moving to the other panel :
-	if ( !dest.equals( panel->otherPanel->virtualPath(), true ) ) {
+	else if ( !dest.equals( panel->otherPanel->virtualPath(), true ) ) {
 		// you can rename only *one* file not a batch,
 		// so a batch dest must alwayes be a directory
 		if ( fileNames.count() > 1 ) dest.adjustPath(1);
@@ -494,6 +526,40 @@ void ListPanelFunc::mkdir() {
 	} // for
 }
 
+KURL ListPanelFunc::getVirtualBaseURL() {
+	if( files()->vfs_getType() != vfs::VIRT || otherFunc()->files()->vfs_getType() == vfs::VIRT )
+		return KURL();
+	
+	QStringList fileNames;
+	panel->getSelectedNames( &fileNames );
+	
+	KURL::List* fileUrls = files() ->vfs_getFiles( &fileNames );
+	if( fileUrls->count() == 0 )
+		return KURL();
+	
+	KURL base = (*fileUrls)[ 0 ].upURL();
+	
+	if( base.protocol() == "virt" ) // is it a virtual subfolder?
+		return KURL();          // --> cannot keep the directory structure
+	
+	for( unsigned i=1; i < fileUrls->count(); i++ ) {
+		if( base.isParentOf( (*fileUrls)[ i ] ) )
+			continue;
+		if( base.protocol() != (*fileUrls)[ i ].protocol() )
+			return KURL();
+		
+		do {
+			KURL oldBase = base;
+			base = base.upURL();
+			if( oldBase.equals( base, true ) )
+				return KURL();
+			if( base.isParentOf( (*fileUrls)[ i ] ) )
+				break;
+		}while( true );
+	}
+	return base;
+}
+
 void ListPanelFunc::copyFiles() {
 	PreserveMode pmode = PM_DEFAULT;
 
@@ -503,11 +569,12 @@ void ListPanelFunc::copyFiles() {
 		return ;  // safety
 
 	KURL dest = panel->otherPanel->virtualPath();
+	KURL virtualBaseURL;
 
 	// confirm copy
 	krConfig->setGroup( "Advanced" );
 	if ( krConfig->readBoolEntry( "Confirm Copy", _ConfirmCopy ) ) {
-		bool preserveDate = krConfig->readBoolEntry( "PreserveDate", _PreserveDate );
+		bool preserveAttrs = krConfig->readBoolEntry( "PreserveAttributes", _PreserveAttributes );
 		QString s;
 
   if( fileNames.count() == 1 )
@@ -516,18 +583,26 @@ void ListPanelFunc::copyFiles() {
     s = i18n("Copy %n file to:", "Copy %n files to:", fileNames.count());
 
 		// ask the user for the copy dest
-		dest = KChooseDir::getDir(s, dest, panel->virtualPath(), preserveDate );
+		virtualBaseURL = getVirtualBaseURL();
+		dest = KChooseDir::getDir(s, dest, panel->virtualPath(), preserveAttrs, virtualBaseURL );
 		if ( dest.isEmpty() ) return ; // the user canceled
-		if( preserveDate )
-			pmode = PM_PRESERVE_DATE;
+		if( preserveAttrs )
+			pmode = PM_PRESERVE_ATTR;
 		else
 			pmode = PM_NONE;
 	}
 
 	KURL::List* fileUrls = files() ->vfs_getFiles( &fileNames );
 
+	if( !virtualBaseURL.isEmpty() ) {
+		// keep the directory structure for virtual paths
+		VirtualCopyJob *vjob = new VirtualCopyJob( &fileNames, files(), dest, virtualBaseURL, pmode, KIO::CopyJob::Copy, false, true );
+		connect( vjob, SIGNAL( result( KIO::Job* ) ), this, SLOT( refresh() ) );
+		if ( dest.equals( panel->otherPanel->virtualPath(), true ) )
+			connect( vjob, SIGNAL( result( KIO::Job* ) ), panel->otherPanel->func, SLOT( refresh() ) );
+	}
 	// if we are  not copying to the other panel :
-	if ( !dest.equals( panel->otherPanel->virtualPath(), true ) ) {
+	else if ( !dest.equals( panel->otherPanel->virtualPath(), true ) ) {
 		// you can rename only *one* file not a batch,
 		// so a batch dest must alwayes be a directory
 		if ( fileNames.count() > 1 ) dest.adjustPath(1);
@@ -572,6 +647,12 @@ void ListPanelFunc::deleteFiles(bool reallyDelete) {
 		if ( !reallyDelete && trash && files() ->vfs_getType() == vfs::NORMAL ) {
 			s = i18n( "Do you really want to move this item to the trash?", "Do you really want to move these %n items to the trash?", fileNames.count() );
 			b = i18n( "&Trash" );
+		} else if( files() ->vfs_getType() == vfs::VIRT && files()->vfs_getOrigin().equals( KURL("virt:/"), true ) ) {
+			s = i18n( "Do you really want to delete this virtual item (physical files stay untouched)?", "Do you really want to delete these virtual items (physical files stay untouched)?", fileNames.count() );
+			b = i18n( "&Delete" );
+		} else if( files() ->vfs_getType() == vfs::VIRT ) {
+			s = i18n( "<qt>Do you really want to delete this item <b>physically</b> (not just removing it from the virtual items)?</qt>", "<qt>Do you really want to delete these %n items <b>physically</b> (not just removing them from the virtual items)?</qt>", fileNames.count() );
+			b = i18n( "&Delete" );
 		} else {
 			s = i18n( "Do you really want to delete this item?", "Do you really want to delete these %n items?", fileNames.count() );
 			b = i18n( "&Delete" );
@@ -596,10 +677,10 @@ void ListPanelFunc::deleteFiles(bool reallyDelete) {
 		// verify non-empty dirs delete... (only for normal vfs)
 		if ( emptyDirVerify && vf->vfile_isDir() && !vf->vfile_isSymLink() ) {
 			dir.setPath( panel->virtualPath().path() + "/" + ( *name ) );
-			if ( dir.entryList(QDir::All | QDir::AccessMask).count() > 2 ) {
+			if ( dir.entryList(QDir::All | QDir::System | QDir::Hidden ).count() > 2 ) {
 				switch ( KMessageBox::warningYesNoCancel( krApp,
-				                                          i18n( "Directory " ) + ( *name ) + i18n( " is not empty!\nSkip this one or Delete All?" ),
-				                                          QString::null, i18n( "&Skip" ), i18n( "&Delete All" ) ) ) {
+																		i18n( "<qt><p>Directory <b>%1</b> is not empty!</p><p>Skip this one or Delete All?</p></qt>" ).arg(*name),
+																		QString::null, i18n( "&Skip" ), i18n( "&Delete All" ) ) ) {
 						case KMessageBox::Cancel :
 						return ;
 						case KMessageBox::No :
@@ -650,9 +731,8 @@ void ListPanelFunc::execute( QString& name ) {
 	QString protocol = origin.isLocalFile() ? KrServices::registerdProtocol( vf->vfile_getMime() ) : "";
 
 	if ( protocol == "tar" || protocol == "krarc" ) {
-		QString type = vf->vfile_getMime().right( 4 );
-		if ( vf->vfile_getMime().contains( "-rar" ) )
-			type = "-rar";
+		bool encrypted;
+		QString type = KRarcHandler::getType( encrypted, vf->vfile_getUrl().path(), vf->vfile_getMime(), false );
 		if ( !KRarcHandler::arcHandled( type ) )   // if the specified archive is disabled delete the protocol
 			protocol = "";
 	}
@@ -692,19 +772,23 @@ void ListPanelFunc::pack() {
 	if ( fileNames.count() == 1 )
 		defaultName = fileNames.first();
 	// ask the user for archive name and packer
-	new PackGUI( defaultName, panel->otherPanel->virtualPath().prettyURL(), fileNames.count(), fileNames.first() );
+	new PackGUI( defaultName, vfs::pathOrURL( panel->otherPanel->virtualPath(), -1 ), fileNames.count(), fileNames.first() );
 	if ( PackGUI::type == QString::null )
 		return ; // the user canceled
 
 	// check for partial URLs	
-	if( !PackGUI::destination.contains(":/") && !PackGUI::destination.startsWith("/")  ){
+	if( !PackGUI::destination.contains(":/") && !PackGUI::destination.startsWith("/") ){
 		PackGUI::destination = panel->virtualPath().prettyURL()+"/"+PackGUI::destination;
 	}
 	
-	bool packToOtherPanel = ( PackGUI::destination == panel->otherPanel->virtualPath().prettyURL() );
+	QString destDir = PackGUI::destination;
+	if( !destDir.endsWith( "/" ) )
+		destDir += "/";
+	
+	bool packToOtherPanel = ( destDir == panel->otherPanel->virtualPath().prettyURL(1) );
 
 	// on remote URL-s first pack into a temp file then copy to its right place
-	KURL destURL = vfs::fromPathOrURL( PackGUI::destination + "/" + PackGUI::filename + "." + PackGUI::type );
+	KURL destURL = vfs::fromPathOrURL( destDir + PackGUI::filename + "." + PackGUI::type );
 	KTempFile *tempDestFile = 0;
 	QString arcFile;
 	if ( destURL.isLocalFile() )
@@ -722,19 +806,16 @@ void ListPanelFunc::pack() {
 	}
 
 	if (  QFileInfo( arcFile ).exists() ) {
-		QString msg = i18n( "The Archive " ) + PackGUI::filename + "." + PackGUI::type+
-		              i18n(" already exists. Do you want to overwrite the archive ?\n");
-		if( PackGUI::type == "zip" ){
-			msg = msg + i18n("(ZIP will replace identically named entries in the zip archive or add entries for new names)"); 
-		} else {
-			msg = msg+ ("(all data in previous archive will be lost)");
+		QString msg = i18n( "<qt><p>The archive <b>%1.%2</b> already exists. Do you want to overwrite it?</p><p>All data in the previous archive will be lost!</p></qt>").arg(PackGUI::filename).arg(PackGUI::type);
+		if( PackGUI::type == "zip" ) {
+			msg = i18n( "<qt><p>The archive <b>%1.%2</b> already exists. Do you want to overwrite it?</p><p>Zip will replace identically named entries in the zip archive or add entries for new names.</p></qt>").arg(PackGUI::filename).arg(PackGUI::type);
 		}
 		if ( KMessageBox::warningContinueCancel( krApp,msg,QString::null,i18n( "&Overwrite" ))
 		        == KMessageBox::Cancel )
 			return ; // stop operation
 	}
 	// tell the user to wait
-	krApp->startWaiting( i18n( "Counting files to pack" ), 0 );
+	krApp->startWaiting( i18n( "Counting files to pack" ), 0, true );
 
 	// get the files to be packed:
 	files() ->vfs_getFiles( &fileNames );
@@ -763,7 +844,7 @@ void ListPanelFunc::pack() {
 	// we must chdir() first because we supply *names* not URL's
 	QString save = getcwd( 0, 0 );
 	chdir( arcDir.local8Bit() );
-	KRarcHandler::pack( fileNames, PackGUI::type, arcFile, totalFiles + totalDirs );
+	KRarcHandler::pack( fileNames, PackGUI::type, arcFile, totalFiles + totalDirs, PackGUI::extraProps );
 	chdir( save.local8Bit() );
 
 	// delete the temporary directory if created
@@ -788,7 +869,6 @@ void ListPanelFunc::testArchive() {
 		return ; // safety
 
 	KURL arcURL = files() ->vfs_getFile( arcName );
-	QString type = files() ->vfs_search( arcName ) ->vfile_getMime().right( 4 );
 	QString url = QString::null;
 
 	// download the file if it's on a remote filesystem
@@ -801,14 +881,20 @@ void ListPanelFunc::testArchive() {
 	} else
 		url = arcURL.path( -1 );
 
+	QString mime = files() ->vfs_search( arcName ) ->vfile_getMime();
+	bool encrypted = false;
+	QString type = KRarcHandler::getType( encrypted, url, mime );
+	
 	// check we that archive is supported
 	if ( !KRarcHandler::arcSupported( type ) ) {
 		KMessageBox::sorry( krApp, i18n( "%1, unknown archive type." ).arg( arcName ) );
 		return ;
 	}
-
+	
+	QString password = encrypted ? KRarcHandler::getPassword( url ) : QString::null;
+	
 	// test the archive
-	if ( KRarcHandler::test( url, type ) )
+	if ( KRarcHandler::test( url, type, password ) )
 		KMessageBox::information( krApp, i18n( "%1, test passed." ).arg( arcName ) );
 	else
 		KMessageBox::error( krApp, i18n( "%1, test failed!" ).arg( arcName ) );
@@ -870,17 +956,19 @@ void ListPanelFunc::unpack() {
 
 		// determining the type
 		QString mime = files() ->vfs_search( arcName ) ->vfile_getMime();
-		QString type = mime.right( 4 );
-		if ( mime.contains( "-rar" ) )
-			type = "-rar";
+		bool encrypted = false;
+		QString type = KRarcHandler::getType( encrypted, url, mime );
 
 		// check we that archive is supported
 		if ( !KRarcHandler::arcSupported( type ) ) {
 			KMessageBox::sorry( krApp, i18n( "%1, unknown archive type" ).arg( arcName ) );
 			continue;
 		}
+		
+		QString password = encrypted ? KRarcHandler::getPassword( url ) : QString::null;
+		
 		// unpack the files
-		KRarcHandler::unpack( url, type, dest.path( -1 ) );
+		KRarcHandler::unpack( url, type, password, dest.path( -1 ) );
 
 		// remove the downloaded file if necessary
 		if ( url != arcURL.path( -1 ) )
@@ -1054,6 +1142,14 @@ vfs* ListPanelFunc::files() {
 
 
 void ListPanelFunc::copyToClipboard( bool move ) {
+	if( files()->vfs_getOrigin().equals( KURL("virt:/"), true ) ) {
+		if( move )
+			KMessageBox::error( krApp, i18n( "Cannot cut a virtual URL collection to the clipboard!" ) );
+		else
+			KMessageBox::error( krApp, i18n( "Cannot copy a virtual URL collection onto the clipboard!" ) );
+		return;
+	}
+	
 	QStringList fileNames;
 
 	panel->getSelectedNames( &fileNames );
@@ -1064,6 +1160,10 @@ void ListPanelFunc::copyToClipboard( bool move ) {
 	if ( fileUrls ) {
 		KRDrag * urlData = KRDrag::newDrag( *fileUrls, move, krApp->mainView, "krusader" );
 		QApplication::clipboard() ->setData( urlData );
+		
+		if( move && files()->vfs_getType() == vfs::VIRT )
+			( static_cast<virt_vfs*>( files() ) )->vfs_removeFiles( &fileNames );
+		
 		delete fileUrls;
 	}
 }
@@ -1078,10 +1178,8 @@ void ListPanelFunc::pasteFromClipboard() {
 
 		KURL destUrl = panel->virtualPath();
 
-		KIO::Job* job = PreservingCopyJob::createCopyJob( PM_DEFAULT, urls,
-			 destUrl, cutSelection ? KIO::CopyJob::Move : KIO::CopyJob::Copy, false, true );
-		job->setAutoErrorHandlingEnabled( true );
-		connect( job, SIGNAL( result( KIO::Job* ) ), SLOTS, SLOT( refresh() ) );
+		files()->vfs_addFiles( &urls, cutSelection ? KIO::CopyJob::Move : KIO::CopyJob::Copy, otherFunc()->files(),
+			"", PM_DEFAULT );
 	}
 }
 
