@@ -41,23 +41,57 @@
 #include "krsearchmod.h"
 #include "krsearchdialog.h"
 
-#include <time.h>
-#include <kglobal.h>
 #include <kinputdialog.h>
 #include <qregexp.h>
 #include <qfontmetrics.h>
 #include <kmessagebox.h>
-#include <klocale.h>
 #include <kpopupmenu.h>
 #include <qcursor.h>
 #include <qclipboard.h>
 #include <qheader.h>
+#include <kurldrag.h>
+#include <../kicons.h>
+
+class SearchListView : public QListView
+{
+public:
+  SearchListView( QWidget * parent, const char * name ) : QListView( parent, name )
+  {
+  }
+
+  void startDrag() 
+  {
+    KURL::List urls;
+
+    QListViewItem * item = firstChild();
+    while( item )
+    {
+      if( item->isSelected() )
+      {
+         QString name = item->text(1);
+         name += (name.endsWith( "/" ) ? item->text(0) : "/" + item->text(0) );
+         urls.push_back( vfs::fromPathOrURL( name ) );
+      }
+      item = item->nextSibling();
+    }
+
+    if( urls.count() == 0 )
+      return;
+
+    KURLDrag *d = new KURLDrag(urls, this);
+    d->setPixmap( FL_LOADICON( "file" ), QPoint( -7, 0 ) );
+    d->dragCopy();
+  }
+};
+
+
 
 KrSearchDialog *KrSearchDialog::SearchDialog = 0;
 
 QString KrSearchDialog::lastSearchText = "*";
 int KrSearchDialog::lastSearchType = 0;
 bool KrSearchDialog::lastSearchForCase = false;
+bool KrSearchDialog::lastRemoteContentSearch = false;
 bool KrSearchDialog::lastContainsWholeWord = false;
 bool KrSearchDialog::lastContainsWithCase = true;
 bool KrSearchDialog::lastSearchInSubDirs = true;
@@ -111,7 +145,7 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
 
   searcherTabs = new QTabWidget( this, "searcherTabs" );
 
-  filterTabs = FilterTabs::addTo( searcherTabs, FilterTabs::Default );
+  filterTabs = FilterTabs::addTo( searcherTabs, FilterTabs::Default | FilterTabs::HasRemoteContentSearch );
   generalFilter = (GeneralFilter *)filterTabs->get( "GeneralFilter" );
 
   resultTab = new QWidget( searcherTabs, "resultTab" );
@@ -142,7 +176,7 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
 
   // creating the result list view
 
-  resultsList = new QListView( resultTab, "resultsList" );
+  resultsList = new SearchListView( resultTab, "resultsList" );
   resultsList->addColumn( i18n( "Name" ) );
   resultsList->addColumn( i18n( "Location" ) );
   resultsList->addColumn( i18n( "Size" ) );
@@ -150,6 +184,7 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   resultsList->addColumn( i18n( "Permissions" ) );
 
   resultsList->setSorting(1); // sort by location
+  resultsList->setSelectionMode( QListView::Extended );
 
   // fix the results list
   // => make the results font smaller
@@ -248,6 +283,7 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
     generalFilter->searchFor->lineEdit()->selectAll();
     generalFilter->ofType->setCurrentItem( lastSearchType );
     generalFilter->searchForCase->setChecked( lastSearchForCase );
+    generalFilter->remoteContentSearch->setChecked( lastRemoteContentSearch );
     generalFilter->containsWholeWord->setChecked( lastContainsWholeWord );
     generalFilter->containsTextCase->setChecked( lastContainsWithCase );
     generalFilter->searchInDirs->setChecked( lastSearchInSubDirs );
@@ -258,7 +294,6 @@ KrSearchDialog::KrSearchDialog( QString profile, QWidget* parent,  const char* n
   }
   else
     profileManager->loadProfile( profile ); // important: call this _after_ you've connected profileManager ot the loadFromProfile!!
-
 }
 
 void KrSearchDialog::closeDialog( bool isAccept )
@@ -286,6 +321,7 @@ void KrSearchDialog::closeDialog( bool isAccept )
   lastSearchText = generalFilter->searchFor->currentText();
   lastSearchType = generalFilter->ofType->currentItem();
   lastSearchForCase = generalFilter->searchForCase->isChecked();
+  lastRemoteContentSearch = generalFilter->remoteContentSearch->isChecked();
   lastContainsWholeWord = generalFilter->containsWholeWord->isChecked();
   lastContainsWithCase = generalFilter->containsTextCase->isChecked();
   lastSearchInSubDirs = generalFilter->searchInDirs->isChecked();
@@ -320,7 +356,7 @@ void KrSearchDialog::found(QString what, QString where, KIO::filesize_t size, ti
   struct tm* t=localtime((time_t *)&mtime);
   QDateTime tmp(QDate(t->tm_year+1900, t->tm_mon+1, t->tm_mday), QTime(t->tm_hour, t->tm_min));
   ResultListViewItem *it =new ResultListViewItem(resultsList, what,
-  	 where.replace(QRegExp("\\\\"),"#"), size, KGlobal::locale()->formatDateTime(tmp), perm);
+  	 where.replace(QRegExp("\\\\"),"#"), size, tmp, perm);
   QString totals = QString(i18n("Found %1 matches.")).arg(resultsList->childCount());
   foundLabel->setText(totals);
 
@@ -429,6 +465,8 @@ void KrSearchDialog::closeEvent(QCloseEvent *e)
 
 void KrSearchDialog::keyPressEvent(QKeyEvent *e)
 {
+  KKey pressedKey( e );
+
   if( isSearching && e->key() == Key_Escape ) /* at searching we must not close the window */
   {
     stopSearch();         /* so we simply stop searching */
@@ -450,6 +488,11 @@ void KrSearchDialog::keyPressEvent(QKeyEvent *e)
       viewCurrent();
       return;
     }
+    else if( Krusader::actCopy->shortcut().contains( pressedKey ) )
+    {
+      copyToClipBoard();
+      return;
+    }
   }
 
   QDialog::keyPressEvent( e );
@@ -463,7 +506,7 @@ void KrSearchDialog::editCurrent()
     QString name = current->text(1);
     name += (name.endsWith( "/" ) ? current->text(0) : "/" + current->text(0) );
     KURL url = vfs::fromPathOrURL( name );
-    KrViewer::edit( url );
+    KrViewer::edit( url, this );
   }
 }
 
@@ -475,15 +518,16 @@ void KrSearchDialog::viewCurrent()
     QString name = current->text(1);
     name += (name.endsWith( "/" ) ? current->text(0) : "/" + current->text(0) );
     KURL url = vfs::fromPathOrURL( name );
-    KrViewer::view( url );
+    KrViewer::view( url, this );
   }
 }
 
 void KrSearchDialog::rightClickMenu(QListViewItem *item, const QPoint&, int)
 {
   // these are the values that will exist in the menu
-  #define EDIT_FILE_ID        110
-  #define VIEW_FILE_ID        111
+  #define EDIT_FILE_ID                110
+  #define VIEW_FILE_ID                111
+  #define COPY_SELECTED_TO_CLIPBOARD  112
   //////////////////////////////////////////////////////////
   if (!item)
     return;
@@ -492,8 +536,9 @@ void KrSearchDialog::rightClickMenu(QListViewItem *item, const QPoint&, int)
   KPopupMenu popup;
   popup.insertTitle(i18n("Krusader Search"));
 
-  popup.insertItem(i18n("View File (F3)"),VIEW_FILE_ID);
-  popup.insertItem(i18n("Edit File (F4)"),EDIT_FILE_ID);
+  popup.insertItem(i18n("View File (F3)"),            VIEW_FILE_ID);
+  popup.insertItem(i18n("Edit File (F4)"),            EDIT_FILE_ID);
+  popup.insertItem(i18n("Copy selected to clipboard"),COPY_SELECTED_TO_CLIPBOARD);
 
   int result=popup.exec(QCursor::pos());
 
@@ -506,6 +551,9 @@ void KrSearchDialog::rightClickMenu(QListViewItem *item, const QPoint&, int)
     case EDIT_FILE_ID:
       editCurrent();
       break;
+    case COPY_SELECTED_TO_CLIPBOARD:
+      copyToClipBoard();
+      break;
     default:    // the user clicked outside of the menu
       break;
   }
@@ -553,4 +601,28 @@ void KrSearchDialog::feedToListBox()
   closeDialog();
 }
 
+void KrSearchDialog::copyToClipBoard()
+{
+  KURL::List urls;
+
+  QListViewItem * item = resultsList->firstChild();
+  while( item )
+  {
+    if( item->isSelected() )
+    {
+       QString name = item->text(1);
+       name += (name.endsWith( "/" ) ? item->text(0) : "/" + item->text(0) );
+       urls.push_back( vfs::fromPathOrURL( name ) );
+    }
+    item = item->nextSibling();
+  }
+
+  if( urls.count() == 0 )
+    return;
+
+  KURLDrag *d = new KURLDrag(urls, this);
+  d->setPixmap( FL_LOADICON( "file" ), QPoint( -7, 0 ) );
+  QApplication::clipboard()->setData( d );
+}
+
 #include "krsearchdialog.moc"
