@@ -67,6 +67,12 @@ ftp_vfs::~ftp_vfs() {
 }
 
 void ftp_vfs::slotAddFiles( KIO::Job *, const KIO::UDSEntryList& entries ) {
+	int rwx = -1;
+	
+	QString prot = vfs_origin.protocol();
+	if( prot == "krarc" || prot == "tar" || prot == "zip" )
+		rwx = PERM_ALL;
+	
 	KIO::UDSEntryListConstIterator it = entries.begin();
 	KIO::UDSEntryListConstIterator end = entries.end();
 
@@ -95,7 +101,7 @@ void ftp_vfs::slotAddFiles( KIO::Job *, const KIO::UDSEntryList& entries ) {
 
 		// create a new virtual file object
 		if ( kfi.user().isEmpty() )
-			temp = new vfile( name, size, perm, mtime, symLink, getuid(), getgid(), mime, symDest, mode );
+			temp = new vfile( name, size, perm, mtime, symLink, getuid(), getgid(), mime, symDest, mode, rwx );
 		else {
 			QString currentUser = vfs_origin.user();
 			if ( currentUser.contains( "@" ) )  /* remove the FTP proxy tags from the username */
@@ -107,7 +113,14 @@ void ftp_vfs::slotAddFiles( KIO::Job *, const KIO::UDSEntryList& entries ) {
 					currentUser = ""; // empty, but not QString::null
 				}
 			}
-			temp = new vfile( name, size, perm, mtime, symLink, kfi.user(), kfi.group(), currentUser, mime, symDest, mode );
+#if KDE_IS_VERSION(3,5,0)
+			temp = new vfile( name, size, perm, mtime, symLink,
+			                  kfi.user(), kfi.group(), currentUser, 
+			                  mime, symDest, mode, rwx, kfi.ACL().asString(),
+			                  kfi.defaultACL().asString() );
+#else
+			temp = new vfile( name, size, perm, mtime, symLink, kfi.user(), kfi.group(), currentUser, mime, symDest, mode, rwx );
+#endif
 		}
 
 #if KDE_IS_VERSION(3,4,0)
@@ -120,7 +133,7 @@ void ftp_vfs::slotAddFiles( KIO::Job *, const KIO::UDSEntryList& entries ) {
 		temp->vfile_setUrl( kfi.url() );
 #endif
 		temp->vfile_setIcon( kfi.iconName() );
-		addToList( temp );
+		foundVfile( temp );
 	}
 }
 
@@ -149,8 +162,12 @@ bool ftp_vfs::populateVfsList( const KURL& origin, bool showHidden ) {
 	QString errorMsg = QString::null;
 	if ( !origin.isValid() )
 		errorMsg = i18n( "Malformed URL:\n%1" ).arg( origin.url() );
-	if ( !KProtocolInfo::supportsListing( origin ) )
-		errorMsg = i18n( "Protocol not supported by Krusader:\n%1" ).arg( origin.url() );
+	if ( !KProtocolInfo::supportsListing( origin ) ) {
+		if( origin.protocol() == "ftp" && KProtocolInfo::supportsReading( origin ) ) 
+			errorMsg = i18n( "Krusader doesn't support FTP access via HTTP.\nIf it is not the case, please check and change the Proxy settings in kcontrol." );
+		else
+			errorMsg = i18n( "Protocol not supported by Krusader:\n%1" ).arg( origin.url() );
+	}
 
 	if ( !errorMsg.isEmpty() ) {
 		if ( !quietMode ) KMessageBox::sorry( krApp, errorMsg );
