@@ -54,7 +54,9 @@ QIntDict<char> *KRpermHandler::currentGroups = 0L;
 QIntDict<QString> *KRpermHandler::uidCache = 0L;
 QIntDict<QString> *KRpermHandler::gidCache = 0L;
 
-char KRpermHandler::writeable( QString perm, gid_t gid, uid_t uid ) {
+char KRpermHandler::writeable( QString perm, gid_t gid, uid_t uid, int rwx ) {
+	if( rwx != -1 )
+		return ( rwx & W_OK ) ? ALLOWED_PERM : NO_PERM;
 	// root override
 	if ( getuid() == 0 )
 		return ALLOWED_PERM;
@@ -70,7 +72,9 @@ char KRpermHandler::writeable( QString perm, gid_t gid, uid_t uid ) {
 	return NO_PERM;
 }
 
-char KRpermHandler::readable( QString perm, gid_t gid, uid_t uid ) {
+char KRpermHandler::readable( QString perm, gid_t gid, uid_t uid, int rwx ) {
+	if( rwx != -1 )
+		return ( rwx & R_OK ) ? ALLOWED_PERM : NO_PERM;
 	// root override
 	if ( getuid() == 0 )
 		return ALLOWED_PERM;
@@ -86,7 +90,9 @@ char KRpermHandler::readable( QString perm, gid_t gid, uid_t uid ) {
 	return NO_PERM;
 }
 
-char KRpermHandler::executable( QString perm, gid_t gid, uid_t uid ) {
+char KRpermHandler::executable( QString perm, gid_t gid, uid_t uid, int rwx ) {
+	if( rwx != -1 )
+		return ( rwx & X_OK ) ? ALLOWED_PERM : NO_PERM;
 	// first check other permissions.
 	if ( perm[ 9 ] != '-' ) return ALLOWED_PERM;
 	// now check group permission
@@ -124,7 +130,10 @@ bool KRpermHandler::fileExecutable( QString localFile ) {
 }
 
 QString KRpermHandler::mode2QString( mode_t m ) {
-	QString perm = "----------";
+	char perm[ 11 ];
+	for( int i=0; i != 10; i++ )
+		perm[ i ] = '-';
+	perm[ 10 ] = 0;
 
 	if ( S_ISLNK( m ) ) perm[ 0 ] = 'l';  // check for symLink
 	if ( S_ISDIR( m ) ) perm[ 0 ] = 'd';  // check for directory
@@ -145,7 +154,7 @@ QString KRpermHandler::mode2QString( mode_t m ) {
 	if ( m & 0001 ) perm[ 9 ] = 'x';
 	if ( m & 01000 ) perm[ 9 ] = 't';
 
-	return perm;
+	return QString( perm );
 }
 
 void KRpermHandler::init() {
@@ -175,7 +184,7 @@ void KRpermHandler::init() {
 	uid_t* uid_temp;
 	while ( ( pass = getpwent() ) != 0L ) {
 		uid_temp = new uid_t( pass->pw_uid );
-		passwdCache->insert( qstrdup( pass->pw_name ), uid_temp );
+		passwdCache->insert( pass->pw_name, uid_temp );
 		uidCache->insert( pass->pw_uid, new QString( pass->pw_name ) );
 	}
 	delete pass;
@@ -186,7 +195,7 @@ void KRpermHandler::init() {
 	gid_t* gid_temp;
 	while ( ( gr = getgrent() ) != 0L ) {
 		gid_temp = new gid_t( gr->gr_gid );
-		groupCache->insert( qstrdup( gr->gr_name ), gid_temp );
+		groupCache->insert( gr->gr_name, gid_temp );
 		gidCache->insert( gr->gr_gid, new QString( gr->gr_name ) );
 	}
 	delete gr;
@@ -270,6 +279,8 @@ bool KRpermHandler::fileExist( QString path, QString name ) {
 }
 
 QString KRpermHandler::parseSize( KIO::filesize_t val ) {
+	return KGlobal::locale()->formatNumber(QString::number(val), false, 0);	
+#if 0
 	QString temp;
 	temp.sprintf( "%llu", val );
 	if ( temp.length() <= 3 ) return temp;
@@ -281,7 +292,9 @@ QString KRpermHandler::parseSize( KIO::filesize_t val ) {
 		i += 3;
 	}
 	size = size + temp.right( 3 );
+							
 	return size;
+#endif
 }
 
 QString KRpermHandler::date2qstring( QString date ) {
