@@ -54,6 +54,16 @@
 #include "../resources.h"
 #include "../krslots.h"
 
+// header files for ACL
+#if KDE_IS_VERSION(3,5,0)
+#ifdef HAVE_POSIX_ACL
+#include <sys/acl.h>
+#ifdef HAVE_NON_POSIX_ACL_EXTENSIONS
+#include <acl/libacl.h>
+#endif
+#endif
+#endif
+
 normal_vfs::normal_vfs(QObject* panel):vfs(panel), watcher(0) {
   vfs_type=NORMAL;
 }
@@ -110,18 +120,21 @@ bool normal_vfs::populateVfsList(const KURL& origin, bool showHidden){
 		if (name=="." || name == "..") continue;
 	  
 		vfile* temp = vfileFromName(name);
-    addToList(temp);
+    foundVfile(temp);
   }
 	// clean up
 	closedir(dir);
 	
-	watcher = new KDirWatch();
-	// connect the watcher
-  connect(watcher,SIGNAL(dirty(const QString&)),this,SLOT(vfs_slotDirty(const QString&)));
-  connect(watcher,SIGNAL(created(const QString&)),this, SLOT(vfs_slotCreated(const QString&)));
-  connect(watcher,SIGNAL(deleted(const QString&)),this, SLOT(vfs_slotDeleted(const QString&)));	
-  watcher->addDir(vfs_getOrigin().path(-1),true); //start watching the new dir
-  watcher->startScan(true);
+	if( panelConnected )
+	{
+		watcher = new KDirWatch();
+		// connect the watcher
+		connect(watcher,SIGNAL(dirty(const QString&)),this,SLOT(vfs_slotDirty(const QString&)));
+		connect(watcher,SIGNAL(created(const QString&)),this, SLOT(vfs_slotCreated(const QString&)));
+		connect(watcher,SIGNAL(deleted(const QString&)),this, SLOT(vfs_slotDeleted(const QString&)));	
+		watcher->addDir(vfs_getOrigin().path(-1),true); //start watching the new dir
+		watcher->startScan(true);
+	}
 
   return true;
 }
@@ -226,9 +239,10 @@ void normal_vfs::vfs_rename(const QString& fileName,const QString& newName){
 
 vfile* normal_vfs::vfileFromName(const QString& name){
 	QString path = vfs_workingDir()+"/"+name;
+	QCString fileName = path.local8Bit();
 	
 	KDE_struct_stat stat_p;
-	KDE_lstat(path.local8Bit(),&stat_p);
+	KDE_lstat(fileName.data(),&stat_p);
 	KIO::filesize_t size = stat_p.st_size;
 	QString perm = KRpermHandler::mode2QString(stat_p.st_mode);
 	bool symLink= S_ISLNK(stat_p.st_mode);
@@ -241,7 +255,7 @@ vfile* normal_vfs::vfileFromName(const QString& name){
 	bzero(symDest,256); 
 	if( S_ISLNK(stat_p.st_mode) ){  // who the link is pointing to ?
 		int endOfName=0;
-		endOfName=readlink(path.local8Bit(),symDest,256);
+		endOfName=readlink(fileName.data(),symDest,256);
 		if ( endOfName != -1 ){
 			if ( QDir(QString::fromLocal8Bit( symDest ) ).exists() ) perm[0] = 'd';
 			if ( !QDir(vfs_workingDir()).exists( QString::fromLocal8Bit ( symDest ) ) ) mime = "Broken Link !";
@@ -249,13 +263,88 @@ vfile* normal_vfs::vfileFromName(const QString& name){
 		else krOut << "Failed to read link: "<< path<<endl;
 	}
 	
+	int rwx = 0;
+	if( ::access( fileName.data(), R_OK ) == 0 )
+		rwx |= R_OK;
+	if( ::access( fileName.data(), W_OK ) == 0 )
+		rwx |= W_OK;
+	if( ::access( fileName.data(), X_OK ) == 0 )
+		rwx |= X_OK;
+	
 	// create a new virtual file object
 	vfile* temp=new vfile(name,size,perm,stat_p.st_mtime,symLink,stat_p.st_uid,
-                          stat_p.st_gid,mime,QString::fromLocal8Bit( symDest ),stat_p.st_mode);
+                          stat_p.st_gid,mime,QString::fromLocal8Bit( symDest ),stat_p.st_mode, rwx);
 	temp->vfile_setUrl( mimeUrl );
 	return temp;
 }
 
+void normal_vfs::getACL( vfile *file, QString &acl, QString &defAcl )
+{
+	acl = defAcl = QString::null;
+#if KDE_IS_VERSION(3,5,0) && defined( HAVE_POSIX_ACL )
+	QCString fileName = file->vfile_getUrl().path( -1 ).local8Bit();
+#if HAVE_NON_POSIX_ACL_EXTENSIONS
+	if ( acl_extended_file( fileName.data() ) )
+	{
+#endif
+		acl = getACL( fileName.data(), ACL_TYPE_ACCESS );
+		if( file->vfile_isDir() )
+			defAcl = getACL( fileName.data(), ACL_TYPE_DEFAULT );
+#if HAVE_NON_POSIX_ACL_EXTENSIONS
+	}
+#endif
+#endif
+}
+
+QString normal_vfs::getACL( const QString & path, int type )
+{
+#if KDE_IS_VERSION(3,5,0) && defined( HAVE_POSIX_ACL )
+	acl_t acl = 0;
+	// do we have an acl for the file, and/or a default acl for the dir, if it is one?
+	if ( ( acl = acl_get_file( path.data(), type ) ) != 0 )
+	{
+		bool aclExtended = false;
+		
+#if HAVE_NON_POSIX_ACL_EXTENSIONS
+		aclExtended = acl_equiv_mode( acl, 0 );
+#else
+		acl_entry_t entry;
+		int ret = acl_get_entry( acl, ACL_FIRST_ENTRY, &entry );
+		while ( ret == 1 ) {
+			acl_tag_t currentTag;
+			acl_get_tag_type( entry, &currentTag );
+			if ( currentTag != ACL_USER_OBJ &&
+				currentTag != ACL_GROUP_OBJ &&
+				currentTag != ACL_OTHER )
+			{
+				aclExtended = true;
+				break;
+			}
+			ret = acl_get_entry( acl, ACL_NEXT_ENTRY, &entry );
+		}
+#endif
+		
+		if ( !aclExtended )
+		{
+			acl_free( acl );
+			acl = 0;
+		}
+	}
+	
+	if( acl == 0 )
+		return QString::null;
+	
+	char *aclString = acl_to_text( acl, 0 );
+	QString ret = QString::fromLatin1( aclString );
+	acl_free( (void*)aclString );
+	acl_free( acl );
+	
+	return ret;
+#else
+	return QString::null;
+#endif
+}
+
 void normal_vfs::vfs_slotRefresh()
 {
 	krConfig->setGroup("Advanced");
@@ -274,7 +363,7 @@ bool normal_vfs::burstRefresh(const QString& path ){
 		}
 		disconnect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
 		connect( &refreshTimer, SIGNAL( timeout() ), this, SLOT( vfs_slotRefresh() ) );
-		dirty = true;
+		postponedRefreshURL = fromPathOrURL(path);
 		return true;
 	}
 	return false;
@@ -282,7 +371,7 @@ bool normal_vfs::burstRefresh(const QString& path ){
 
 void normal_vfs::vfs_slotDirty(const QString& path){ 
 	if( disableRefresh ){
-		dirty = true;
+		postponedRefreshURL = fromPathOrURL(path);
 		return;
 	}
 	
@@ -304,7 +393,7 @@ void normal_vfs::vfs_slotDirty(const QString& path){
 
 void normal_vfs::vfs_slotCreated(const QString& path){  
 	if( disableRefresh ){
-		dirty = true;
+		postponedRefreshURL = fromPathOrURL(path);
 		return;
 	}	
 	
@@ -325,7 +414,7 @@ void normal_vfs::vfs_slotCreated(const QString& path){
 
 void normal_vfs::vfs_slotDeleted(const QString& path){ 
 	if( disableRefresh ){
-		dirty = true;
+		postponedRefreshURL = fromPathOrURL(path);
 		return;
 	}
 	
