@@ -37,9 +37,11 @@
 #include <qdatetime.h>
 // KDE includes
 #include <kmimetype.h>
+#include <kdeversion.h>
 // Krusader includes
 #include "vfile.h"
 #include "krpermhandler.h"
+#include "normal_vfs.h"
 
 #include <kdebug.h>
 
@@ -52,7 +54,9 @@ vfile::vfile(const QString& name,	                  // useful construtor
              const gid_t group,
              const QString& mime,
              const QString& symDest,
-             const mode_t mode){
+             const mode_t mode,
+             const int rwx)
+{
 	vfile_name=name;
 	vfile_size=size;
 	vfile_owner=QString::null;
@@ -66,8 +70,11 @@ vfile::vfile(const QString& name,	                  // useful construtor
 	vfile_mimeType=mime;
 	vfile_symDest=symDest;
 	vfile_mode=mode;
+	vfile_isdir = ( perm[ 0 ] == 'd' );
 	if (vfile_isDir() && !vfile_symLink )
 		vfile_size = 0;
+	vfile_rwx = rwx;
+	vfile_acl_loaded = false;
 }
 
 vfile::vfile(const QString& name,	                  // useful construtor
@@ -80,7 +87,10 @@ vfile::vfile(const QString& name,	                  // useful construtor
              const QString& userName,
              const QString& mime,
              const QString& symDest,
-             const mode_t mode){
+             const mode_t mode,
+             const int rwx,
+             const QString& aclString,
+             const QString& aclDfltString ){
 	vfile_name=name;
 	vfile_size=size;
 	vfile_owner=owner;
@@ -94,27 +104,44 @@ vfile::vfile(const QString& name,	                  // useful construtor
 	vfile_mimeType=mime;
 	vfile_symDest=symDest;
 	vfile_mode=mode;
+	vfile_isdir = ( perm[ 0 ] == 'd' );
 	if ( vfile_isDir() && !vfile_symLink )
 		vfile_size = 0;
+	vfile_acl = aclString;
+	vfile_def_acl = aclDfltString;
+	vfile_has_acl = !aclString.isNull() || !aclDfltString.isNull();
+	vfile_acl_loaded = true;
+	vfile_rwx = rwx;
 }
 
 char vfile::vfile_isReadable() const {
-	if( vfile_userName.isNull() )
-		return KRpermHandler::readable(vfile_perm,vfile_groupId,vfile_ownerId);
+	if( vfile_rwx == PERM_ALL )
+		return ALLOWED_PERM;
+	else if( vfile_userName.isNull() )
+		return KRpermHandler::readable(vfile_perm,vfile_groupId,vfile_ownerId,vfile_rwx);
 	else
 		return KRpermHandler::ftpReadable(vfile_owner, vfile_userName, vfile_perm);
 }
 
 char vfile::vfile_isWriteable() const {
-	if( vfile_userName.isNull() )
-		return KRpermHandler::writeable(vfile_perm,vfile_groupId,vfile_ownerId);
+	if( vfile_rwx == PERM_ALL )
+		return ALLOWED_PERM;
+	else if( vfile_userName.isNull() )
+		return KRpermHandler::writeable(vfile_perm,vfile_groupId,vfile_ownerId,vfile_rwx);
 	else
 		return KRpermHandler::ftpWriteable(vfile_owner, vfile_userName, vfile_perm);
 }
 
 char vfile::vfile_isExecutable() const {
-	if( vfile_userName.isNull() )
-		return KRpermHandler::executable(vfile_perm,vfile_groupId,vfile_ownerId);
+	if( vfile_rwx == PERM_ALL )
+	{
+		if(( vfile_mode & 0111 ) || vfile_isdir )
+			return ALLOWED_PERM;
+		else
+			return NO_PERM;
+	}
+	else if( vfile_userName.isNull() )
+		return KRpermHandler::executable(vfile_perm,vfile_groupId,vfile_ownerId,vfile_rwx);
 	else
 		return KRpermHandler::ftpExecutable(vfile_owner, vfile_userName, vfile_perm);
 }
@@ -122,7 +149,7 @@ char vfile::vfile_isExecutable() const {
 const QString& vfile::vfile_getMime(bool fast){
 	if( vfile_mimeType == QString::null ){ // mimetype == "" is OK so don't check mimetype.empty() !
 		vfile_mimeType = KMimeType::findByURL( vfile_getUrl(),vfile_getMode(),vfile_getUrl().isLocalFile(),fast)->name();
-		if( vfile_mimeType.contains("directory") ) vfile_perm[0] = 'd';
+		if( vfile_mimeType.contains("directory") ) vfile_perm[0] = 'd', vfile_isdir = true;
 	}
 	return vfile_mimeType;
 }
@@ -139,6 +166,28 @@ const QString& vfile::vfile_getGroup(){
 	return vfile_group;
 }
 
+const QString& vfile::vfile_getACL(){
+	if( !vfile_acl_loaded )
+		vfile_loadACL();
+	return vfile_acl;
+}
+
+const QString& vfile::vfile_getDefaultACL(){
+	if( !vfile_acl_loaded )
+		vfile_loadACL();
+	return vfile_def_acl;
+}
+
+void vfile::vfile_loadACL()
+{
+	if( vfile_url.isLocalFile() )
+	{
+		normal_vfs::getACL( this, vfile_acl, vfile_def_acl );
+		vfile_has_acl = !vfile_acl.isNull() || !vfile_def_acl.isNull();
+	}
+	vfile_acl_loaded = true;
+}
+
 const KIO::UDSEntry vfile::vfile_getEntry() {
 	KIO::UDSEntry entry;
 	KIO::UDSAtom atom;
@@ -185,37 +234,76 @@ const KIO::UDSEntry vfile::vfile_getEntry() {
 		entry.append(atom);
 	}
 
+#if KDE_IS_VERSION(3,5,0)
+	if( !vfile_acl_loaded )
+		vfile_loadACL();
+	if( vfile_has_acl ) {
+		atom.m_uds = KIO::UDS_EXTENDED_ACL;
+		atom.m_long = 1;
+		entry.append( atom );
+		
+		if( !vfile_acl.isNull() )
+		{
+			atom.m_uds = KIO::UDS_ACL_STRING;
+			atom.m_str = vfile_acl;
+			entry.append(atom);
+		}
+		
+		if( !vfile_def_acl.isNull() )
+		{
+			atom.m_uds = KIO::UDS_DEFAULT_ACL_STRING;
+			atom.m_str = vfile_acl;
+			entry.append(atom);
+		}
+	}
+#endif
+
 	return entry;
 }
 
 bool vfile::operator==(const vfile& vf) const{
 	bool equal;
 	
+	if( !vfile_acl_loaded )
+		const_cast<vfile *>( this )->vfile_loadACL();
+	if( !vf.vfile_acl_loaded )
+		const_cast<vfile *>( &vf )->vfile_loadACL();
+	
 	equal = (vfile_name     == vf.vfile_getName()   ) &&
 	        (vfile_size     == vf.vfile_getSize()   ) &&
 	        (vfile_perm     == vf.vfile_getPerm()   ) &&
 	        (vfile_time_t   == vf.vfile_getTime_t() ) &&
 	        (vfile_ownerId  == vf.vfile_getUid()    ) &&
-	        (vfile_groupId  == vf.vfile_getGid()    ) ;
+	        (vfile_groupId  == vf.vfile_getGid()    ) &&
+	        (vfile_has_acl  == vf.vfile_has_acl     ) &&
+	        (!vfile_has_acl || 
+	        (vfile_acl      == vf.vfile_acl         ) &&
+	        (vfile_def_acl  == vf.vfile_def_acl     ) );;
 	
 	return equal;
 }
 
 vfile& vfile::operator= (const vfile& vf){
-	vfile_name     = vf.vfile_name     ;
-	vfile_size     = vf.vfile_size     ;
-	vfile_mode     = vf.vfile_mode     ;
-	vfile_ownerId  = vf.vfile_ownerId  ;
-	vfile_groupId  = vf.vfile_groupId  ;
-	vfile_owner    = vf.vfile_owner    ;
-	vfile_group    = vf.vfile_group    ;
-	vfile_userName = vf.vfile_userName ;
-	vfile_perm     = vf.vfile_perm     ;
-	vfile_time_t   = vf.vfile_time_t   ;
-	vfile_symLink  = vf.vfile_symLink  ;
-	vfile_mimeType = vf.vfile_mimeType ;
-	vfile_symDest  = vf.vfile_symDest  ;
-	vfile_url      = vf.vfile_url      ;
+	vfile_name       = vf.vfile_name      ;
+	vfile_size       = vf.vfile_size      ;
+	vfile_mode       = vf.vfile_mode      ;
+	vfile_ownerId    = vf.vfile_ownerId   ;
+	vfile_groupId    = vf.vfile_groupId   ;
+	vfile_owner      = vf.vfile_owner     ;
+	vfile_group      = vf.vfile_group     ;
+	vfile_userName   = vf.vfile_userName  ;
+	vfile_perm       = vf.vfile_perm      ;
+	vfile_time_t     = vf.vfile_time_t    ;
+	vfile_symLink    = vf.vfile_symLink   ;
+	vfile_mimeType   = vf.vfile_mimeType  ;
+	vfile_symDest    = vf.vfile_symDest   ;
+	vfile_url        = vf.vfile_url       ;
+	vfile_isdir      = vf.vfile_isdir     ;
+	vfile_has_acl    = vf.vfile_has_acl   ;
+	vfile_acl        = vf.vfile_acl       ;
+	vfile_def_acl    = vf.vfile_def_acl   ;
+	vfile_rwx        = vf.vfile_rwx       ;
+	vfile_acl_loaded = vf.vfile_acl_loaded;
 	
 	return (*this);
 } 
