@@ -47,6 +47,7 @@
 #include <qstringlist.h>
 #include <qtextstream.h>
 #include <kdebug.h>
+#include <dcopobject.h>
 
 #ifdef __KJSEMBED__
 class KrJS;
@@ -65,25 +66,28 @@ class Expander;
 class KMountMan;
 class KrBookmarkHandler;
 class PopularUrls;
+class QueueManager;
 
 //static QTextOStream krOut(stdout);
 #define krOut kdDebug(50010)
 
-class Krusader : public KParts::MainWindow {
+class Krusader : public KParts::MainWindow, public DCOPObject {
     Q_OBJECT
   public:
     Krusader();
-    ~Krusader();
+    virtual ~Krusader();
     void refreshView();				 // re-create the main view
+    void configChanged();
     /**
      * This returns a defferent icon if krusader runs with root-privileges
      * @return a character string with the specitif icon-name
      */
-    static char* privIcon();
+    static const char* privIcon();
     static QStringList supportedTools(); // find supported tools
-	 void importKeyboardShortcuts(QString filename);
-	 void exportKeyboardShortcuts(QString filename);
-		
+
+    virtual bool process (const QCString &fun, const QByteArray &data, QCString &replyType, QByteArray &replyData);
+    void moveToTop();
+
   public slots:
     // increase the internal progress bar
     void incProgress( KProcess *, char *buffer, int buflen );
@@ -91,8 +95,9 @@ class Krusader : public KParts::MainWindow {
     // in use by Krusader only
     void saveSettings();
     void savePosition();
-    void quitKrusader();
     void updateGUI( bool enforce = false );
+    void slotClose();
+    void setDirectExit() { directExit = true; }
 
   protected:
     bool queryExit() {
@@ -115,25 +120,33 @@ class Krusader : public KParts::MainWindow {
     KConfig *config;    // allow everyone to access the config
     KIconLoader *iconLoader; // the app's icon loader
 	 PopularUrls *popularUrls; // holds a sorted list of the most popular urls visited
+	 QueueManager *queueManager;
     // Actions
     static KAction *actProperties, *actPack, *actUnpack, *actTest, *actCompare, *actCmdlinePopup;
-    static KAction *actCalculate, *actSelect, *actUnselect, *actSelectAll, *actLocate;
+    static KAction *actCalculate, *actSelect, *actUnselect, *actSelectAll, *actLocate, *actSwitchFullScreenTE;
     static KAction *actUnselectAll, *actInvert, *actSync, *actDiskUsage, *actSavePosition, *actCompDirs;
     static KAction *actHomeTerminal, *actFTPConnect, *actFTPNewConnect, *actFTPDisconnect, *actProfiles;
-    static KAction *actExecFilter, *actCustomFilter, *actMountMan, *actNewTool, *actSwapPanels;
+    static KAction *actExecFilter, *actCustomFilter, *actMountMan, *actNewTool, *actSwapPanels, *actSwapSides;
     static KAction *actKonfigurator, *actToolsSetup, *actBack, *actRoot, *actFind, *actDirUp;
     static KAction *actSelectColorMask, *actMultiRename, *actAllFilter, *actOpenLeftBm, *actOpenRightBm;
     static KAction *actNewTab, *actDupTab, *actCloseTab, *actPreviousTab, *actNextTab, *actSplit; 
     static KAction *actCombine, *actUserMenu, *actManageUseractions, *actSyncDirs, *actSyncBrowse;
     static KAction *actF2, *actF3, *actF4, *actF5, *actF6, *actF7, *actF8, *actF9, *actF10;
     static KAction *actPopularUrls, *actLocationBar, *actJumpBack, *actSetJumpBack, *actCreateChecksum, *actMatchChecksum;
+    static KAction *actDetailedView, *actBriefView, *actCopy, *actPaste;
     static KToggleAction *actToggleTerminal, *actVerticalMode;
-    static KRadioAction *actMarkNewerAndSingle, *actMarkNewer, *actMarkSingle, 
-                        *actMarkDifferentAndSingle, *actMarkDifferent;
+    static KRadioAction *actSelectNewerAndSingle, *actSelectNewer, *actSelectSingle, 
+                        *actSelectDifferentAndSingle, *actSelectDifferent;
+    /** actions for setting the execution mode of commands from commanddline */
+    static KRadioAction *actExecStartAndForget,
+                        *actExecCollectSeparate,*actExecCollectTogether,
+                        *actExecTerminalExternal,*actExecTerminalEmbedded;
     KToggleAction *actToggleFnkeys, *actToggleCmdline, *actShowToolBar,
                   *actShowStatusBar, *actToggleHidden, *actCompareDirs;
 
     static KRadioAction **compareArray[];
+    /** actions for setting the execution mode of commands from commanddline */
+    static KRadioAction **execTypeArray[];
 
     // return a path to a temp dir or file we can use.
     QString getTempDir();
@@ -152,14 +165,13 @@ class Krusader : public KParts::MainWindow {
     static KPopupMenu *userActionMenu;
     static UserMenu *userMenu;
     static UserAction *userAction;
-    static Expander *expander;
 	 static KrBookmarkHandler *bookman;
 
     #ifdef __KJSEMBED__
     static KrJS *js;
     static KAction *actShowJSConsole;
     #endif
-  
+
   signals:
     void changeMessage( QString );
 
@@ -168,6 +180,8 @@ class Krusader : public KParts::MainWindow {
     QPoint       oldPos;
     QSize        oldSize;
     bool         isStarting;
+    bool         isExiting;
+    bool         directExit;
 };
 
 // main modules
@@ -238,7 +252,6 @@ class Krusader : public KParts::MainWindow {
 #define krUserMenu        Krusader::App->actUserMenu
 #define krUserActionMenu      Krusader::App->userActionMenu
 #define krUserAction      Krusader::App->userAction
-#define krExpander        Krusader::App->expander
 #define krF2				  Krusader::App->actF2
 #define krF3				  Krusader::App->actF3
 #define krF4				  Krusader::App->actF4
