@@ -59,13 +59,18 @@ class KrusaderView : public QWidget  {
 
 public:
 	KrusaderView(QWidget *parent=0);
-	~KrusaderView(){}
-  void start(QStringList leftTabs, int leftActiveTab, QStringList rightTabs, int rightActiveTab);
+	virtual ~KrusaderView(){}
+  void start(QStringList leftTabs, QStringList leftTypes, QValueList<int> leftProps, int leftActiveTab, 
+             QStringList rightTabs, QStringList rightTypes, QValueList<int> rightProps, int rightActiveTab,
+             bool leftSideActive);
   void cmdLineFocus();  // command line receive's keyboard focus
   void cmdLineUnFocus();// return focus from command line to active panel
   inline PanelManager *activeManager() const { return (activePanel==left ? leftMng : rightMng); }
   inline PanelManager *inactiveManager() const { return (activePanel==left ? rightMng : leftMng); }
   QValueList<int> getTerminalEmulatorSplitterSizes();
+  virtual bool eventFilter ( QObject * watched, QEvent * e );
+  /** if the KonsolePart for the Terminal Emulator is not yet loaded, load it */
+  void createTE();
   
 public slots:
   void slotCurrentChanged(QString p);
@@ -77,6 +82,9 @@ public slots:
   void panelSwitch();
   void toggleVerticalMode();
   
+  void focusTerminalEmulator();
+  void switchFullScreenTE();
+  
   void profiles( QString profileName = QString::null );  
   void loadPanelProfiles( QString group );
   void savePanelProfiles( QString group );
