@@ -35,12 +35,17 @@
 #include <kstandarddirs.h>
 #include <ksplashscreen.h>
 #include <unistd.h>
+#include <signal.h>
+#include <qeventloop.h>
 
 // Krusader includes
 #include "krusader.h"
 #include "krslots.h"
 #include "krusaderapp.h"
 #include "defaults.h"
+#include <dcopclient.h>
+#include <kstartupinfo.h>
+#include <stdlib.h>
 
 static const char *description =
 	I18N_NOOP("Krusader\nTwin-Panel File Manager for KDE");
@@ -55,6 +60,14 @@ static KCmdLineOptions options[] =
   // INSERT YOUR COMMANDLINE OPTIONS HERE
 };
 
+static void sigterm_handler(int i)
+{
+  fprintf(stderr,"Signal: %d\n",i);
+
+  QApplication::eventLoop()->wakeUp();
+  KApplication::exit( - 15 );
+}
+
 int main(int argc, char *argv[]) {
 
 // ============ begin icon-stuff ===========
@@ -71,12 +84,19 @@ int main(int argc, char *argv[]) {
      hasIcon = true;
   }
 
+  static const char* const icon_text="--icon";
+  const char* icon_name=Krusader::privIcon();
+  char addedParams[strlen(icon_text)+strlen(icon_name)+2];
+
   if ( ! hasIcon ) {
     for ( i = 0; i < argc; ++i )
       myArgv[ i ] = argv[ i ];
 
-    myArgv[ argc ] = "--icon";
-    myArgv[ ++argc ] = Krusader::privIcon();
+    strcpy(addedParams,icon_text);
+    strcpy(addedParams+strlen(icon_text)+1,icon_name);
+
+    myArgv[ argc ] = addedParams;
+    myArgv[ ++argc ] = addedParams+strlen(icon_text)+1;
     myArgv[ ++argc ] = 0;
 
     argv = myArgv;
@@ -92,12 +112,12 @@ int main(int argc, char *argv[]) {
   KAboutData aboutData( "krusader", ( geteuid() ? I18N_NOOP("Krusader") :
                         I18N_NOOP("Krusader - ROOT PRIVILEGES")),
     versionName.latin1(), description, KAboutData::License_GPL,
-    "(c) 2000-2003, Shie Erlich, Rafi Yanai\n(c) 2004-2006, Krusader Krew",
-    "Feedback:\nhttp://www.krusader.org/phpBB/\n\n"
-    "IRC:\nServer: irc.freenode.net, channel: #krusader"
-    ,
+    "(c) 2000-2003, Shie Erlich, Rafi Yanai\n(c) 2004-2007, Krusader Krew",
+    I18N_NOOP("Feedback\nhttp://www.krusader.org/phpBB/\n\n"
+              "IRC\nserver: irc.freenode.net, channel: #krusader"),
     "http://www.krusader.org",
     "krusader@users.sourceforge.net");
+
   aboutData.addAuthor("Rafi Yanai","Author", "yanai@users.sourceforge.net");
   aboutData.addAuthor("Shie Erlich","Author", "erlich@users.sourceforge.net");
   aboutData.addAuthor("Karai Csaba", "Developer", "ckarai@users.sourceforge.net", 0);
@@ -105,10 +125,11 @@ int main(int argc, char *argv[]) {
   aboutData.addAuthor("Jonas Baehr", "Developer", "jonas.baehr@web.de", 0);
   aboutData.addAuthor("Dirk Eschler", "Webmaster and i18n coordinator", "deschler@users.sourceforge.net", 0);
   aboutData.addAuthor("Frank Schoolmeesters", "Documentation and marketing coordinator", "frank_schoolmeesters@yahoo.com", 0);
-aboutData.addAuthor("Richard Holt", "Documentation & Proofing", "richard.holt@gmail.com", 0);
-aboutData.addAuthor("Matej Urbancic", " Marketing & Product Research", "matej.urban@gmail.com", 0);
-  aboutData.addCredit("Andrew Neupokoev", "Killer Logo and Icons for Krusader (contest winner)",
-  		"doom-blue@yandex.ru", 0);
+  aboutData.addAuthor("Richard Holt", "Documentation & Proofing", "richard.holt@gmail.com", 0);
+  aboutData.addAuthor("Matej Urbancic", " Marketing & Product Research", "matej.urban@gmail.com", 0);
+  aboutData.addCredit("Václav Juza", "QA, bug-hunting, patches and general help", "vaclavjuza@gmail.com", 0);
+  aboutData.addCredit("Jiri Palecek", "QA, bug-hunting, patches and general help", "jpalecek@web.de", 0);
+  aboutData.addCredit("Andrew Neupokoev", "Killer Logo and Icons for Krusader (contest winner)", "doom-blue@yandex.ru", 0);
   aboutData.addCredit("The UsefulArts Organization", "Icon for krusader", "mail@usefularts.rg", 0);
   aboutData.addCredit("Gábor Lehel", "Viewer module for 3rd Hand", "illissius@gmail.com", 0);
   aboutData.addCredit("Mark Eatough", "Handbook Proof-Reader", "markeatough@yahoo.com", 0);
@@ -139,12 +160,15 @@ aboutData.addAuthor("Matej Urbancic", " Marketing & Product Research", "matej.ur
   aboutData.addCredit("Kukk Zoltan","Old Hungarian translation","kukkzoli@freemail.hu",0);
   aboutData.addCredit("Arpad Biro","Hungarian translation","biro_arpad@yahoo.com",0);
   aboutData.addCredit("Giuseppe Bordoni", "Italian translation", "geppo@geppozone.com", 0);
-  aboutData.addCredit("UTUMI Hirosi", "Japanese translation", "utuhiro@mx12.freecom.ne.jp", 0);
+  aboutData.addCredit("Hideki Kimura", "Japanese translation", "hangyo1973@gmail.com", 0);
+  aboutData.addCredit("UTUMI Hirosi", "Old Japanese translation", "utuhiro@mx12.freecom.ne.jp", 0);
   aboutData.addCredit("Dovydas Sankauskas", "Lithuanian translation", "laisve@gmail.com", 0);
   aboutData.addCredit("Bruno Queiros", "Portuguese translation", "brunoqueiros@portugalmail.com", 0);
   aboutData.addCredit("Lukasz Janyst","Old Polish translation","ljan@wp.pl",0);
   aboutData.addCredit("Pawel Salawa","Polish translation","boogie@myslenice.one.pl",0);
-  aboutData.addCredit("Dmitry Chernyak","Russian translation","chernyak@mail.ru",0);
+  aboutData.addCredit("Tomek Grzejszczyk","Polish translation","tgrzej@onet.eu",0);
+  aboutData.addCredit("Dmitry A. Bugay","Russian translation","sam@vhnet.ru",0);
+  aboutData.addCredit("Dmitry Chernyak","Old Russian translation","chernyak@mail.ru",0);
   aboutData.addCredit("Sasa Tomic","Serbian translation","stomic@gmx.net",0);
   aboutData.addCredit("Zdenko Podobna","Slovak translation","zdpo@mailbox.sk",0);
   aboutData.addCredit("Matej Urbancic","Slovenian translation","matej.urban@gmail.com",0);
@@ -153,6 +177,7 @@ aboutData.addAuthor("Matej Urbancic", " Marketing & Product Research", "matej.ur
   aboutData.addCredit("Erik Johanssen","Old Swedish translation","erre@telia.com",0);
   aboutData.addCredit("Anders Linden","Old Swedish translation","connyosis@gmx.net",0);
   aboutData.addCredit("Peter Landgren","Swedish translation","peter.talken@telia.com",0);
+  aboutData.addCredit("Bekir Sonat","Turkish translation","bekirsonat@kde.org.tr",0);
   aboutData.addCredit("Ivan Petrouchtchak","Ukrainian translation","connyosis@gmx.net",0);
 
   // Command line arguments ...
@@ -163,7 +188,27 @@ aboutData.addAuthor("Matej Urbancic", " Marketing & Product Research", "matej.ur
 
   // create the application
   KrusaderApp app;
-  
+
+  {
+    KConfigGroupSaver saver(app.config(), "Look&Feel");
+    bool singleInstanceMode = app.config()->readBoolEntry( "Single Instance Mode", _SingleInstanceMode );
+
+    // register with the dcop server
+    DCOPClient* client = KApplication::kApplication() ->dcopClient();
+    if ( !client->attach() )
+       exit( 0 );
+    QCString regName = client->registerAs( KApplication::kApplication() ->name(), !singleInstanceMode );
+    if( singleInstanceMode && regName != KApplication::kApplication()->name() ) {
+      fprintf( stderr, i18n( "Application already running!\n" ).ascii() );
+
+      DCOPClient::mainClient()->send( KApplication::kApplication() ->name(), "Krusader-Interface",
+                                    "moveToTop()", QByteArray() );
+      KStartupInfo::appStarted();
+
+      return 1;
+    }
+  }
+    
   // splash screen - if the user wants one
   KSplashScreen *splash = 0;
   { // don't remove bracket
@@ -178,18 +223,23 @@ aboutData.addAuthor("Matej Urbancic", " Marketing & Product Research", "matej.ur
   }
   } // don't remove bracket
 
-  Krusader *krusader = new Krusader();
+  Krusader krusader;
+  
+  // catching SIGTERM, SIGHUP, SIGQUIT
+  signal(SIGTERM,sigterm_handler);
+  signal(SIGPIPE,sigterm_handler);
+  signal(SIGHUP,sigterm_handler);
+
   // make sure we receive X's focus in/out events
-  QObject::connect(&app, SIGNAL(windowActive()), krusader->slot, SLOT(windowActive()));
-  QObject::connect(&app, SIGNAL(windowInactive()), krusader->slot, SLOT(windowInactive()));
-	
+  QObject::connect(&app, SIGNAL(windowActive()), krusader.slot, SLOT(windowActive()));
+  QObject::connect(&app, SIGNAL(windowInactive()), krusader.slot, SLOT(windowInactive()));
+
   // and set krusader to be the main widget in it
-  app.setMainWidget(krusader);
-  krusader->show();
+  app.setMainWidget(&krusader);
   
   // hide splashscreen
   if (splash) {
-    splash->finish(krusader);
+    splash->finish( &krusader );
     delete splash;
   }
 
